function [status,DiffField] = CompareDSGEModel(DSGEModel,OrigDSGEModel)
% CompareDSGEModel: Compares the current DSGEModel structure with the last saved structure. Returns 0
%                   if they are different and 1 otherwise.
%
% USAGE:
%
%       [status,DiffField] = CompareDSGEModel(DSGEModel,OrigDSGEModel)
%
% REQUIRED INPUT:  DSGEModel (structure) whose fields contain all required information
%                            about the model, such as input files, variable and sample
%                            data. Actual observations are not stored in this file.
%
%                  OrigDSGEModel (structure) whose fields are identical to the DSGEModel
%                            structure, but where OrigDSGEModel contains the last saved
%                            values, while DSGEModel has values that may have changed since
%                            the last save.
%
% REQUIRED OUTPUT: status (boolean) which is one if the structures have identical values and
%                            0 otherwise.
%
% OPTIONAL OUTPUT: DiffField (string vector) with the name of the first discovered difference
%                            if status is zero.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2025 European Central Bank.
%
%                       First version: August 9, 2006.
%                        This version: January 9, 2025.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 22-08-2006: Added the field "InitializeKalman".
%
% * 30-08-2006: Added the fields "OverwriteDraws", "MarginalLikelihoodValue", "SequentialStartIteration",
%               "SequentialStepLength", "SequentialML", "CoverageStart", "CoverageIncrement", and "CoverageEnd".
%
% * 17-10-2006: Fixed a bug when comparing StateShockPositions to their original values and StateVariablePositions to their
%               original values.
%
% * 31-10-2006: Added the fields "DAToleranceValue", "RiccatiMaxIterations", and "RiccatiToleranceValue".
%
% * 20-11-2006: Added the fields "StateCovConst", "UseOwnInitialState".
%
% * 27-11-2006: made sure that the string matrices "DSGEModel.StateShockNames" and "DSGEModel.StateVariableNames" are
%               compared with their original matrices.
%
% * 28-11-2006: Added the fields "PosteriorDrawsValue", "SampleBatchValue", "ParallelChainsValue", "BurnInValue",
%               "MHInitialScaleFactor", "MHScaleFactor", and "RandomWeightValue".
%
% * 04-12-2006: Added the fields "ShockGroupNames" and "ShockGroups".
%
% * 07-12-2006: Added the fields "OptMaxIterationsValue", "OptToleranceValue", "MaximizeAlgorithmValue", "StepLengthHessian",
%               "NumberOfGridPoints", "FiniteDifferenceHessian", "CheckOptimum", "CheckTransformedOptimum", "GridWidth",
%               "IRHorizon", "PriorKernel", "KernelDensityValue", and "KernelDensityEstimator".
%
% * 15-12-2006: Added the field "PosteriorDensityValue".
%
% * 18-12-2006: Added the field "RandomNumberValue".
%
% * 21-12-2006: Added the field "MaxForecastHorizon".
%
% * 22-12-2006: Added the field "FreqParameterReest".
%
% * 05-01-2007: Added the field "ShockGroupColors".
%
% * 11-01-2007: Added the fields "BVARLags", "HarmonicLagDecayValue", "CrossEqTightnessValue", "OverallTightnessValue",
%               "PriorType", and "PriorDiffMeanValue".
%
% * 12-01-2007: Added the fields "OmegaPriorType", "WishartType", "VarianceTightnessValue", "WishartDFValue",
%               "SteadyStatePriorFile", "BVARY", and "BVARX".
%
% * 22-02-2007: Added the fields "NumPredPathsValue" and "PostDrawsUsageValue".
%
% * 26-02-2007: Added the field "RandomizeDraws".
%
% * 28-02-2007: Added the field "ConfidenceBandBaseColor".
%
% * 08-03-2007: Added the fields "ConditionalShocks" and "ConditionalVariables".
%
% * 03-04-2007: Added the field "PostDrawsPercentValue".
%
% * 10-04-2007: Added the field "InverseHessianEstimator".
%
% * 16-04-2007: Added the field "MaxCorrelationValue".
%
% * 25-04-2007: Added the fields "ScenarioShocks", and "ScenarioVariables".
%
% * 26-04-2007: Added the fields "AnnScenarioValue" and "ScenarioValue".
%
% * 02-05-2007: Added the field "ScenarioParameters".
%
% * 03-05-2007: Added the field "PredictionEvent".
%
% * 04-05-2007: Made sure the function treats potential Inf and -Inf values correctly for the "PredictionEvent" matrix.
%
% * 23-08-2007: Added the field "AdjustPredictionPaths".
%
% * 28-09-2007: Added the field "ObsVariableScenarioFile".
%
% * 25-10-2007: The field "FreqParameterReest" is no longer supported.
%
% * 26-10-2007: Added the field "ParameterScenario".
%
% * 06-11-2007: Added the field "OVSComparisonFile".
%
% * 17-12-2007: Added the field "ShockControlMethod".
%
% * 20-12-2007: Added the field "UnitRootStates".
%
% * 02-01-2008: Added the field "KalmanFirstObservation" and removed the field "InitializeKalman".
%
% * 22-01-2008: The field "OVSComparisonFile" is no longer supported.
%
% * 24-01-2008: Added the field "KsiUseCondData".
%
% * 31-01-2008: Added the fields "ShockColorStart" and "ShockColorEnd".
%
% * 18-02-2008: Added the field "ModifiedHessian".
%
% * 16-05-2008: Added the field "AIMTolerance".
%
% * 21-05-2008: Fixed a bug regarding the placement of the tests for the "StateShockPositions" and the
%               "StateVariablePositions".
%
% * 23-05-2008: Updated the documentation.
%
% * 02-07-2008: Added the field "AllowUnitRoot".
%
% * 28-07-2008: Added the field "ParameterScenarioValue".
%
% * 19-12-2008: Updated the documentation.
%
% * 29-01-2009: Added the field "InitializeHessian".
%
% * 12-02-2009: Added the field "ParameterCovMatrix".
%
% * 15-04-2009: Added the fields "ScenarioStateValue", "AnnScenarioStateValue", "StateScenarioShocks",
%               and "StateScenarioVariables".
%
% * 14-07-2009: Added the fields "ZetaConditionalShocks" and "ZetaConditionalVariables".
%
% * 24-09-2009: Added the fields "ObsVarGroups", "ObsVarGroupNames", and "ObsVarGroupColors".
%
% * 06-01-2010: Updated the documentation.
%
% * 26-01-2010: Added the field "DSGEVARShocks".
%
% * 08-03-2010: Added the fields "MarginalLambda" and "JointLambda".
%
% * 04-08-2010: Added the field "ConstrainedStateVariables".
%
% * 05-08-2010: Added the field "ConstrainedStateValue".
%
% * 14-12-2010: Added the fields "CsminwelExtraRuns", "ModelSolver" and "KalmanAlgorithm".
%
% * 16-12-2010: Added the missing field "PosteriorSampler".
%
% * 04-01-2011: Updated the documentation.
%
% * 21-03-2011: Added the fields "MixedConditionalShocks" and "ZetaMixedConditionalShocks".
%
% * 05-04-2011: Deleted the fields "ShockColorStart" and "ShockColorEnd". Replaced these with
%               "ShockColors". Added the field "ShockAliases".
%
% * 15-12-2011: Added the field "MonteCarloFilterDraws".
%
% * 04-01-2012: Updated the documentation.
%
% * 09-02-2012: Added the field "StationaryVAR".
%
% * 22-03-2012: Added the field "PredictionVariables".
%
% * 05-06-2012: Added the field "StateEquationPositions".
%
% * 20-08-2012: Added the field "ConfidenceRegionMethod".
%
% * 28-08-2013: Added the fields "PosteriorDraws" and "Burnin" to allow for user selected number of posterior draws
%               and number of burnin draws.
%
% * 24-01-2014: Updated the documentation.
%
% * 18-08-2014: Added the fields "RhatPosition" and "ZLBSampleT".
%
% * 26-08-2014: Added the field "REqPosition".
%
% * 04-09-2014: Added the field "AdditionalDraws".
%
% * 11-09-2014: Changed the field "RhatPosition" to "RtildePosition".
%
% * 05-01-2015: Updated the documentation.
%
% * 24-08-2015: Added the field "StudenttDegFree".
%
% * 20-01-2016: Updated the documentation.
%
% * 10-02-2017: Updated the documentation.
%
% * 01-04-2017: Added the field "FixedNumParamBlocks".
%
% * 13-04-2017: Added the field "BlockSize".
%
% * 12-05-2017: Added the field "SystemPriorFile".
%
% * 10-08-2017: Added the fields "TemperingStagesValue" and "TemperingLambdaValue".
%
% * 11-08-2017: Added the fields "NumParamBlocks", "MixedDistWeightValue", "SMCInitialScaleFactor",
%               "TargetAcceptanceRateValue", and "ResamplingAlgorithm".
%
% * 15-08-2017: Added the field "SMCNumMHSteps".
%
% * 14-09-2017: Added the field "ResamplingThresholdValue".
%
% * 08-01-2018: Updated the documentation.
%
% * 30-07-2018: Added the field "ModelSolverFile".
%
% * 30-11-2018: Added the fields "ISMaxMixCompValue", "ISInitialDF", "ISWeightShareValue",
%               "ISAddedMixWeightValue", and "ISAddedDF".
%
% * 13-12-2018: Added the field "CoVToleranceValue".
%
% * 21-01-2019: Updated the documentation.
%
% * 07-01-2020: Updated the documentation.
%
% * 06-03-2020: Added the fields "BeliefSystem", "BeliefSystemFile", "ForwardVariablePositions"
%               and "ForwardVariableNames".
%
% * 10-03-2020: Added the fields "BeliefPriorFile" and "BeliefPriorFileSheet".
%
% * 08-05-2020: Added the field "NonCentralGLSMatrix".
%
% * 11-05-2020: Added the field "NoSmoothedStatesForBeliefs".
%
% * 02-07-2020: Removed the field "NonCentralGLSMatrix".
%
% * 03-07-2020: Added the field "FixedBeliefsForProj".
%
% * 25-01-2021: Updated the documentation.
%
% * 28-01-2021: Added the field "AdaptiveLearningModelSolverFile".
%
% * 23-02-2021: Added the fields "TargetVariablePosition", "TargetShockValue" and "TargetEqPosition".
%
% * 11-03-2021: Added the field "ResponseDenominatorPosition".
%
% * 30-08-2021: Added the fields "DSGEImportIVFile", "ALDSGEImportIVFile", "DSGEVARMargImportIVFile" and
%               "DSGEVARImportIVFile".
%
% * 04-01-2022: Updated the documentation.
%
% * 13-01-2022: Added the field "ShowEstimationLog".
%
% * 23-11-2022: Added the fields "DynarePath" and "DynareModelFile".
%
% * 30-11-2022: Removed the field "DynarePath".
%
% * 03-01-2023: Updated the documentation.
%
% * 23-01-2023: Added the field "DriverFunctions".
%
% * 17-02-2023: Added the field "RunScriptFile" and removed "AdditionalDraws".
%
% * 05-10-2023: Added the field "MonteCarloFilterDrawsAL".
%
% * 23-11-2023: Added the field "ZLBRuleType".
%
% * 08-01-2024: Updated the documentation.
%
% * 18-03-2024: Added the optional output variable "DiffField".
%
% * 09-01-2025: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

status = 0;
if nargout==2;
   DiffField = '';
end;
if strcmp(lower(DSGEModel.DataConstructionFile),lower(OrigDSGEModel.DataConstructionFile))==0;
   if nargout==2;
      DiffField = 'DataConstructionFile';
   end;
   return;
end;
if strcmp(lower(DSGEModel.MeasurementEquationFile),lower(OrigDSGEModel.MeasurementEquationFile))==0;
   if nargout==2;
      DiffField = 'MeasurementEquationFile';
   end;
   return;
end;
if strcmp(lower(DSGEModel.PriorFile),lower(OrigDSGEModel.PriorFile))==0;
   if nargout==2;
      DiffField = 'PriorFile';
   end;
   return;
end;
if strcmp(lower(DSGEModel.PriorFileSheet),lower(OrigDSGEModel.PriorFileSheet))==0;
   if nargout==2;
      DiffField = 'PriorFileSheet';
   end;
   return;
end;
if strcmp(lower(DSGEModel.SystemPriorFile),lower(OrigDSGEModel.SystemPriorFile))==0;
   if nargout==2;
      DiffField = 'SystemPriorFile';
   end;
   return;
end;
if strcmp(lower(DSGEModel.UpdateParameterFile),lower(OrigDSGEModel.UpdateParameterFile))==0;
   if nargout==2;
      DiffField = 'UpdateParameterFile';
   end;
   return;
end;
if strcmp(lower(DSGEModel.InitializeParameterFile),lower(OrigDSGEModel.InitializeParameterFile))==0;
   if nargout==2;
      DiffField = 'InitializeParameterFile';
   end;
   return;
end;
if strcmp(lower(DSGEModel.AIMFile),lower(OrigDSGEModel.AIMFile))==0;
   if nargout==2;
      DiffField = 'AIMFile';
   end;
   return;
end;
if strcmp(lower(DSGEModel.AIMDataFile),lower(OrigDSGEModel.AIMDataFile))==0;
   if nargout==2;
      DiffField = 'AIMDataFile';
   end;
   return;
end;
if strcmp(lower(DSGEModel.NameOfModel),lower(OrigDSGEModel.NameOfModel))==0;
   if nargout==2;
      DiffField = 'NameOfModel';
   end;
   return;
end;
if strcmp(lower(DSGEModel.OutputDirectory),lower(OrigDSGEModel.OutputDirectory))==0;
   if nargout==2;
      DiffField = 'OutputDirectory';
   end;
   return;
end;
if (isequal(DSGEModel.StateVariableNames,OrigDSGEModel.StateVariableNames)==0)|(length(DSGEModel.StateVariablePositions)~=length(OrigDSGEModel.StateVariablePositions))|(sum(abs(DSGEModel.StateVariablePositions-OrigDSGEModel.StateVariablePositions))>0);
   if nargout==2;
      DiffField = 'StateVariableNames';
   end;
   return;
end;
if (isequal(DSGEModel.StateEquationNames,OrigDSGEModel.StateEquationNames)==0)|(length(DSGEModel.StateEquationPositions)~=length(OrigDSGEModel.StateEquationPositions))|(sum(abs(DSGEModel.StateEquationPositions-OrigDSGEModel.StateEquationPositions))>0)
   if nargout==2;
      DiffField = 'StateEquationNames';
   end;
   return;
end;
if (isequal(DSGEModel.StateShockNames,OrigDSGEModel.StateShockNames)==0)|(length(DSGEModel.StateShockPositions)~=length(OrigDSGEModel.StateShockPositions))|(sum(abs(DSGEModel.StateShockPositions-OrigDSGEModel.StateShockPositions))>0);
   if nargout==2;
      DiffField = 'StateShockNames';
   end;
   return;
end;
if (length(DSGEModel.DSGEVARShocks)~=length(OrigDSGEModel.DSGEVARShocks))|(sum(abs(DSGEModel.DSGEVARShocks-OrigDSGEModel.DSGEVARShocks))>0);
   if nargout==2;
      DiffField = 'DSGEVARShocks';
   end;
   return;
end;
if (length(DSGEModel.MarginalLambda)~=length(OrigDSGEModel.MarginalLambda))|(sum(abs(DSGEModel.MarginalLambda-OrigDSGEModel.MarginalLambda))>0);
   if nargout==2;
      DiffField = 'MarginalLambda';
   end;
   return;
end;
if (length(DSGEModel.JointLambda)~=length(OrigDSGEModel.JointLambda))|(sum(abs(DSGEModel.JointLambda-OrigDSGEModel.JointLambda))>0);
   if nargout==2;
      DiffField = 'JointLambda';
   end;
   return;
end;
if strcmp(DSGEModel.SubBeginYear,OrigDSGEModel.SubBeginYear)==0;
   if nargout==2;
      DiffField = 'SubBeginYear';
   end;
   return;
end;
if strcmp(DSGEModel.SubBeginPeriod,OrigDSGEModel.SubBeginPeriod)==0;
   if nargout==2;
      DiffField = 'SubBeginPeriod';
   end;
   return;
end;
if strcmp(DSGEModel.SubEndYear,OrigDSGEModel.SubEndYear)==0;
   if nargout==2;
      DiffField = 'SubEndYear';
   end;
   return;
end;
if strcmp(DSGEModel.SubEndPeriod,OrigDSGEModel.SubEndPeriod)==0;
   if nargout==2;
      DiffField = 'SubEndPeriod';
   end;
   return;
end;
if abs(DSGEModel.RunInitializeFirst-OrigDSGEModel.RunInitializeFirst)>0;
   if nargout==2;
      DiffField = 'RunInitializeFirst';
   end;
   return;
end;
if abs(DSGEModel.UseDoublingAlgorithm-OrigDSGEModel.UseDoublingAlgorithm)>0;
   if nargout==2;
      DiffField = 'UseDoublingAlgorithm';
   end;
   return;
end;
if abs(DSGEModel.DAMaximumIterationsValue-OrigDSGEModel.DAMaximumIterationsValue)>0;
   if nargout==2;
      DiffField = 'DAMaximumIterationsValue';
   end;
   return;
end;
if abs(DSGEModel.ShowProgress-OrigDSGEModel.ShowProgress)>0;
   if nargout==2;
      DiffField = 'ShowProgress';
   end;
   return;
end;
if abs(DSGEModel.ShowProgressClock-OrigDSGEModel.ShowProgressClock)>0;
   if nargout==2;
      DiffField = 'ShowProgressClock';
   end;
   return;
end;
if abs(DSGEModel.KalmanFirstObservation-OrigDSGEModel.KalmanFirstObservation)>0;
   if nargout==2;
      DiffField = 'KalmanFirstObservation';
   end;
   return;
end;
if abs(DSGEModel.OverwriteDraws-OrigDSGEModel.OverwriteDraws)>0;
   if nargout==2;
      DiffField = 'OverwriteDraws';
   end;
   return;
end;
if abs(DSGEModel.MarginalLikelihoodValue-OrigDSGEModel.MarginalLikelihoodValue)>0;
   if nargout==2;
      DiffField = 'MarginalLikelihoodValue';
   end;
   return;
end;
if abs(DSGEModel.SequentialStartIteration-OrigDSGEModel.SequentialStartIteration)>0;
   if nargout==2;
      DiffField = 'SequentialStartIteration';
   end;
   return;
end;
if abs(DSGEModel.SequentialStepLength-OrigDSGEModel.SequentialStepLength)>0;
   if nargout==2;
      DiffField = 'SequentialStepLength';
   end;
   return;
end;
if abs(DSGEModel.SequentialML-OrigDSGEModel.SequentialML)>0;
   if nargout==2;
      DiffField = 'SequentialML';
   end;
   return;
end;
if abs(DSGEModel.CoverageStart-OrigDSGEModel.CoverageStart)>0;
   if nargout==2;
      DiffField = 'CoverageStart';
   end;
   return;
end;
if abs(DSGEModel.CoverageIncrement-OrigDSGEModel.CoverageIncrement)>0;
   if nargout==2;
      DiffField = 'CoverageIncrement';
   end;
   return;
end;
if abs(DSGEModel.CoverageEnd-OrigDSGEModel.CoverageEnd)>0;
   if nargout==2;
      DiffField = 'CoverageEnd';
   end;
   return;
end;
if abs(DSGEModel.DAToleranceValue-OrigDSGEModel.DAToleranceValue)>0;
   if nargout==2;
      DiffField = 'DAToleranceValue';
   end;
   return;
end;
if abs(DSGEModel.RiccatiMaxIterations-OrigDSGEModel.RiccatiMaxIterations)>0;
   if nargout==2;
      DiffField = 'RiccatiMaxIterations';
   end;
   return;
end;
if abs(DSGEModel.RiccatiToleranceValue-OrigDSGEModel.RiccatiToleranceValue)>0;
   if nargout==2;
      DiffField = 'RiccatiToleranceValue';
   end;
   return;
end;
if abs(DSGEModel.StateCovConst-OrigDSGEModel.StateCovConst)>0;
   if nargout==2;
      DiffField = 'StateCovConst';
   end;
   return;
end;
if abs(DSGEModel.UseOwnInitialState-OrigDSGEModel.UseOwnInitialState)>0;
   if nargout==2;
      DiffField = 'UseOwnInitialState';
   end;
   return;
end;
if (length(DSGEModel.InitialStateValues)~=length(OrigDSGEModel.InitialStateValues))|(sum(abs(DSGEModel.InitialStateValues-OrigDSGEModel.InitialStateValues))>0);
   if nargout==2;
      DiffField = 'InitialStateValues';
   end;
   return;
end;
if abs(DSGEModel.PosteriorDrawsValue-OrigDSGEModel.PosteriorDrawsValue)>0;
   if nargout==2;
      DiffField = 'PosteriorDrawsValue';
   end;
   return;
end;
if isequal(DSGEModel.PosteriorDraws,OrigDSGEModel.PosteriorDraws)==0;
   if nargout==2;
      DiffField = 'PosteriorDraws';
   end;
   return;
end;
if abs(DSGEModel.SampleBatchValue-OrigDSGEModel.SampleBatchValue)>0;
   if nargout==2;
      DiffField = 'SampleBatchValue';
   end;
   return;
end;
if abs(DSGEModel.ParallelChainsValue-OrigDSGEModel.ParallelChainsValue)>0;
   if nargout==2;
      DiffField = 'ParallelChainsValue';
   end;
   return;
end;
if abs(DSGEModel.BurnInValue-OrigDSGEModel.BurnInValue)>0;
   if nargout==2;
      DiffField = 'BurnInValue';
   end;
   return;
end;
if isequal(DSGEModel.BurnIn,OrigDSGEModel.BurnIn)==0;
   if nargout==2;
      DiffField = 'BurnIn';
   end;
   return;
end;
if abs(DSGEModel.MHInitialScaleFactor-OrigDSGEModel.MHInitialScaleFactor)>0;
   if nargout==2;
      DiffField = 'MHInitialScaleFactor';
   end;
   return;
end;
if abs(DSGEModel.MHScaleFactor-OrigDSGEModel.MHScaleFactor)>0;
   if nargout==2;
      DiffField = 'MHScaleFactor';
   end;
   return;
end;
if abs(DSGEModel.RandomWeightValue-OrigDSGEModel.RandomWeightValue)>0;
   if nargout==2;
      DiffField = 'RandomWeightValue';
   end;
   return;
end;
if (isequal(DSGEModel.ShockGroupNames,OrigDSGEModel.ShockGroupNames)==0)|(length(DSGEModel.ShockGroups)~=length(OrigDSGEModel.ShockGroups))|(sum(abs(DSGEModel.ShockGroups-OrigDSGEModel.ShockGroups))>0);
   if nargout==2;
      DiffField = 'ShockGroupNames';
   end;
   return;
end;
if abs(DSGEModel.OptMaxIterationsValue-OrigDSGEModel.OptMaxIterationsValue)>0;
   if nargout==2;
      DiffField = 'OptMaxIterationsValue';
   end;
   return;
end;
if abs(DSGEModel.OptToleranceValue-OrigDSGEModel.OptToleranceValue)>0;
   if nargout==2;
      DiffField = 'OptToleranceValue';
   end;
   return;
end;
if abs(DSGEModel.MaximizeAlgorithmValue-OrigDSGEModel.MaximizeAlgorithmValue)>0;
   if nargout==2;
      DiffField = 'MaximizeAlgorithmValue';
   end;
   return;
end;
if abs(DSGEModel.StepLengthHessian-OrigDSGEModel.StepLengthHessian)>0;
   if nargout==2;
      DiffField = 'StepLengthHessian';
   end;
   return;
end;
if abs(DSGEModel.NumberOfGridPoints-OrigDSGEModel.NumberOfGridPoints)>0;
   if nargout==2;
      DiffField = 'NumberOfGridPoints';
   end;
   return;
end;
if abs(DSGEModel.FiniteDifferenceHessian-OrigDSGEModel.FiniteDifferenceHessian)>0;
   if nargout==2;
      DiffField = 'FiniteDifferenceHessian';
   end;
   return;
end;
if abs(DSGEModel.CheckOptimum-OrigDSGEModel.CheckOptimum)>0;
   if nargout==2;
      DiffField = 'CheckOptimum';
   end;
   return;
end;
if abs(DSGEModel.CheckTransformedOptimum-OrigDSGEModel.CheckTransformedOptimum)>0;
   if nargout==2;
      DiffField = 'CheckTransformedOptimum';
   end;
   return;
end;
if abs(DSGEModel.GridWidth-OrigDSGEModel.GridWidth)>0;
   if nargout==2;
      DiffField = 'GridWidth';
   end;
   return;
end;
if abs(DSGEModel.IRHorizon-OrigDSGEModel.IRHorizon)>0;
   if nargout==2;
      DiffField = 'IRHorizon';
   end;
   return;
end;
if abs(DSGEModel.PriorKernel-OrigDSGEModel.PriorKernel)>0;
   if nargout==2;
      DiffField = 'PriorKernel';
   end;
   return;
end;
if abs(DSGEModel.KernelDensityValue-OrigDSGEModel.KernelDensityValue)>0;
   if nargout==2;
      DiffField = 'KernelDensityValue';
   end;
   return;
end;
if strcmp(DSGEModel.KernelDensityEstimator,OrigDSGEModel.KernelDensityEstimator)==0;
   if nargout==2;
      DiffField = 'KernelDensityEstimator';
   end;
   return;
end;
if abs(DSGEModel.PosteriorDensityValue-OrigDSGEModel.PosteriorDensityValue)>0;
   if nargout==2;
      DiffField = 'PosteriorDensityValue';
   end;
   return;
end;
if abs(DSGEModel.RandomNumberValue-OrigDSGEModel.RandomNumberValue)>0;
   if nargout==2;
      DiffField = 'RandomNumberValue';
   end;
   return;
end;
if abs(DSGEModel.MaxForecastHorizon-OrigDSGEModel.MaxForecastHorizon)>0;
   if nargout==2;
      DiffField = 'MaxForecastHorizon';
   end;
   return;
end;
if (size(DSGEModel.ShockGroupColors,1)~=size(OrigDSGEModel.ShockGroupColors,1))|(max(max(abs(DSGEModel.ShockGroupColors-OrigDSGEModel.ShockGroupColors)))>0);
   if nargout==2;
      DiffField = 'ShockGroupColors';
   end;
   return;
end;
if (size(DSGEModel.ShockColors,1)~=size(OrigDSGEModel.ShockColors,1))|(max(max(abs(DSGEModel.ShockColors-OrigDSGEModel.ShockColors)))>0);
   if nargout==2;
      DiffField = 'ShockColors';
   end;
   return;
end;
if isequal(DSGEModel.ShockAliases,OrigDSGEModel.ShockAliases)==0;
   if nargout==2;
      DiffField = 'ShockAliases';
   end;
   return;
end;
if abs(DSGEModel.BVARLags-OrigDSGEModel.BVARLags)>0;
   if nargout==2;
      DiffField = 'BVARLags';
   end;
   return;
end;
if abs(DSGEModel.HarmonicLagDecayValue-OrigDSGEModel.HarmonicLagDecayValue)>0;
   if nargout==2;
      DiffField = 'HarmonicLagDecayValue';
   end;
   return;
end;
if abs(DSGEModel.CrossEqTightnessValue-OrigDSGEModel.CrossEqTightnessValue)>0;
   if nargout==2;
      DiffField = 'CrossEqTightnessValue';
   end;
   return;
end;
if abs(DSGEModel.OverallTightnessValue-OrigDSGEModel.OverallTightnessValue)>0;
   if nargout==2;
      DiffField = 'OverallTightnessValue';
   end;
   return;
end;
if abs(DSGEModel.PriorType-OrigDSGEModel.PriorType)>0;
   if nargout==2;
      DiffField = 'PriorType';
   end;
   return;
end;
if abs(DSGEModel.PriorLevelMeanValue-OrigDSGEModel.PriorLevelMeanValue)>0;
   if nargout==2;
      DiffField = 'PriorLevelMeanValue';
   end;
   return;
end;
if abs(DSGEModel.PriorDiffMeanValue-OrigDSGEModel.PriorDiffMeanValue)>0;
   if nargout==2;
      DiffField = 'PriorDiffMeanValue';
   end;
   return;
end;
if abs(DSGEModel.OmegaPriorType-OrigDSGEModel.OmegaPriorType)>0;
   if nargout==2;
      DiffField = 'OmegaPriorType';
   end;
   return;
end;
if abs(DSGEModel.WishartType-OrigDSGEModel.WishartType)>0;
   if nargout==2;
      DiffField = 'WishartType';
   end;
   return;
end;
if abs(DSGEModel.VarianceTightnessValue-OrigDSGEModel.VarianceTightnessValue)>0;
   if nargout==2;
      DiffField = 'VarianceTightnessValue';
   end;
   return;
end;
if abs(DSGEModel.WishartDFValue-OrigDSGEModel.WishartDFValue)>0;
   if nargout==2;
      DiffField = 'WishartDFValue';
   end;
   return;
end;
if strcmp(lower(DSGEModel.SteadyStatePriorFile),lower(OrigDSGEModel.SteadyStatePriorFile))==0;
   if nargout==2;
      DiffField = 'SteadyStatePriorFile';
   end;
   return;
end;
if (length(DSGEModel.BVARY)~=length(OrigDSGEModel.BVARY))|(sum(abs(DSGEModel.BVARY-OrigDSGEModel.BVARY))>0);
   if nargout==2;
      DiffField = 'BVARY';
   end;
   return;
end;
if (length(DSGEModel.BVARX)~=length(OrigDSGEModel.BVARX))|(sum(abs(DSGEModel.BVARX-OrigDSGEModel.BVARX))>0);
   if nargout==2;
      DiffField = 'BVARX';
   end;
   return;
end;
if abs(DSGEModel.NumPredPathsValue-OrigDSGEModel.NumPredPathsValue)>0;
   if nargout==2;
      DiffField = 'NumPredPathsValue';
   end;
   return;
end;
if abs(DSGEModel.PostDrawsUsageValue-OrigDSGEModel.PostDrawsUsageValue)>0;
   if nargout==2;
      DiffField = 'PostDrawsUsageValue';
   end;
   return;
end;
if abs(DSGEModel.RandomizeDraws-OrigDSGEModel.RandomizeDraws)>0;
   if nargout==2;
      DiffField = 'RandomizeDraws';
   end;
   return;
end;
if max(abs(DSGEModel.ConfidenceBandBaseColor-OrigDSGEModel.ConfidenceBandBaseColor))>0;
   if nargout==2;
      DiffField = 'ConfidenceBandBaseColor';
   end;
   return;
end;
if (length(DSGEModel.ConditionalShocks)~=length(OrigDSGEModel.ConditionalShocks))|(max(abs(DSGEModel.ConditionalShocks-OrigDSGEModel.ConditionalShocks))>0);
   if nargout==2;
      DiffField = 'ConditionalShocks';
   end;
   return;
end;
if (length(DSGEModel.MixedConditionalShocks)~=length(OrigDSGEModel.MixedConditionalShocks))|(max(abs(DSGEModel.MixedConditionalShocks-OrigDSGEModel.MixedConditionalShocks))>0);
   if nargout==2;
      DiffField = 'MixedConditionalShocks';
   end;
   return;
end;
if (length(DSGEModel.ConditionalVariables)~=length(OrigDSGEModel.ConditionalVariables))|(max(abs(DSGEModel.ConditionalVariables-OrigDSGEModel.ConditionalVariables))>0);
   if nargout==2;
      DiffField = 'ConditionalVariables';
   end;
   return;
end;
if (length(DSGEModel.ZetaConditionalShocks)~=length(OrigDSGEModel.ZetaConditionalShocks))|(max(abs(DSGEModel.ZetaConditionalShocks-OrigDSGEModel.ZetaConditionalShocks))>0);
   if nargout==2;
      DiffField = 'ZetaConditionalShocks';
   end;
   return;
end;
if (length(DSGEModel.ZetaMixedConditionalShocks)~=length(OrigDSGEModel.ZetaMixedConditionalShocks))|(max(abs(DSGEModel.ZetaMixedConditionalShocks-OrigDSGEModel.ZetaMixedConditionalShocks))>0);
   if nargout==2;
      DiffField = 'ZetaMixedConditionalShocks';
   end;
   return;
end;
if (length(DSGEModel.ZetaConditionalVariables)~=length(OrigDSGEModel.ZetaConditionalVariables))|(max(abs(DSGEModel.ZetaConditionalVariables-OrigDSGEModel.ZetaConditionalVariables))>0);
   if nargout==2;
      DiffField = 'ZetaConditionalVariables';
   end;
   return;
end;
if abs(DSGEModel.PostDrawsPercentValue-OrigDSGEModel.PostDrawsPercentValue)>0;
   if nargout==2;
      DiffField = 'PostDrawsPercentValue';
   end;
   return;
end;
if abs(DSGEModel.InverseHessianEstimator-OrigDSGEModel.InverseHessianEstimator)>0;
   if nargout==2;
      DiffField = 'InverseHessianEstimator';
   end;
   return;
end;
if abs(DSGEModel.MaxCorrelationValue-OrigDSGEModel.MaxCorrelationValue)>0;
   if nargout==2;
      DiffField = 'MaxCorrelationValue';
   end;
   return;
end;
if (length(DSGEModel.ScenarioShocks)~=length(OrigDSGEModel.ScenarioShocks))|(max(abs(DSGEModel.ScenarioShocks-OrigDSGEModel.ScenarioShocks))>0);
   if nargout==2;
      DiffField = 'ScenarioShocks';
   end;
   return;
end;
if (length(DSGEModel.ScenarioVariables)~=length(OrigDSGEModel.ScenarioVariables))|(max(abs(DSGEModel.ScenarioVariables-OrigDSGEModel.ScenarioVariables))>0);
   if nargout==2;
      DiffField = 'ScenarioVariables';
   end;
   return;
end;
if abs(DSGEModel.ScenarioValue-OrigDSGEModel.ScenarioValue)>0;
   if nargout==2;
      DiffField = 'ScenarioValue';
   end;
   return;
end;
if abs(DSGEModel.AnnScenarioValue-OrigDSGEModel.AnnScenarioValue)>0;
   if nargout==2;
      DiffField = 'AnnScenarioValue';
   end;
   return;
end;
if (length(DSGEModel.ScenarioParameters)~=length(OrigDSGEModel.ScenarioParameters))|(max(abs(DSGEModel.ScenarioParameters-OrigDSGEModel.ScenarioParameters))>0);
   if nargout==2;
      DiffField = 'ScenarioParameters';
   end;
   return;
end;
if (min(size(DSGEModel.PredictionEvent)==size(OrigDSGEModel.PredictionEvent))==0)|(min(min(DSGEModel.PredictionEvent==OrigDSGEModel.PredictionEvent))==0);
   if nargout==2;
      DiffField = 'PredictionEvent';
   end;
   return;
end;
if abs(DSGEModel.AdjustPredictionPaths-OrigDSGEModel.AdjustPredictionPaths)>0;
   if nargout==2;
      DiffField = 'AdjustPredictionPaths';
   end;
   return;
end;
if abs(DSGEModel.KsiUseCondData-OrigDSGEModel.KsiUseCondData)>0;
   if nargout==2;
      DiffField = 'KsiUseCondData';
   end;
   return;
end;
if strcmp(lower(DSGEModel.ObsVariableScenarioFile),lower(OrigDSGEModel.ObsVariableScenarioFile))==0;
   if nargout==2;
      DiffField = 'ObsVariableScenarioFile';
   end;
   return;
end;
if (length(DSGEModel.ParameterScenario)~=length(OrigDSGEModel.ParameterScenario))|(abs(DSGEModel.ParameterScenario-OrigDSGEModel.ParameterScenario)>0);
   if nargout==2;
      DiffField = 'ParameterScenario';
   end;
   return;
end;
if abs(DSGEModel.ShockControlMethod-OrigDSGEModel.ShockControlMethod)>0;
   if nargout==2;
      DiffField = 'ShockControlMethod';
   end;
   return;
end;
if (isequal(DSGEModel.UnitRootStates,OrigDSGEModel.UnitRootStates)==0)|(length(DSGEModel.UnitRootStates)~=length(OrigDSGEModel.UnitRootStates))|(sum(abs(DSGEModel.UnitRootStates-OrigDSGEModel.UnitRootStates))>0);
   if nargout==2;
      DiffField = 'UnitRootStates';
   end;
   return;
end;
if abs(DSGEModel.ModifiedHessian-OrigDSGEModel.ModifiedHessian)>0;
   if nargout==2;
      DiffField = 'ModifiedHessian';
   end;
   return;
end;
if abs(DSGEModel.AIMTolerance-OrigDSGEModel.AIMTolerance)>0;
   if nargout==2;
      DiffField = 'AIMTolerance';
   end;
   return;
end;
if abs(DSGEModel.AllowUnitRoot-OrigDSGEModel.AllowUnitRoot)>0;
   if nargout==2;
      DiffField = 'AllowUnitRoot';
   end;
   return;
end;
if abs(DSGEModel.ParameterScenarioValue-OrigDSGEModel.ParameterScenarioValue)>0;
   if nargout==2;
      DiffField = 'ParameterScenarioValue';
   end;
   return;
end;
if abs(DSGEModel.InitializeHessian-OrigDSGEModel.InitializeHessian)>0;
   if nargout==2;
      DiffField = 'InitializeHessian';
   end;
   return;
end;
if strcmp(lower(DSGEModel.ParameterCovMatrix),lower(OrigDSGEModel.ParameterCovMatrix))==0;
   if nargout==2;
      DiffField = 'ParameterCovMatrix';
   end;
   return;
end;
if abs(DSGEModel.ConstrainedStateValue-OrigDSGEModel.ConstrainedStateValue)>0;
   if nargout==2;
      DiffField = 'ConstrainedStateValue';
   end;
   return;
end;
if abs(DSGEModel.ScenarioStateValue-OrigDSGEModel.ScenarioStateValue)>0;
   if nargout==2;
      DiffField = 'ScenarioStateValue';
   end;
   return;
end;
if abs(DSGEModel.AnnScenarioStateValue-OrigDSGEModel.AnnScenarioStateValue)>0;
   if nargout==2;
      DiffField = 'AnnScenarioStateValue';
   end;
   return;
end;
if (length(DSGEModel.StateScenarioShocks)~=length(OrigDSGEModel.StateScenarioShocks))|(max(abs(DSGEModel.StateScenarioShocks-OrigDSGEModel.StateScenarioShocks))>0);
   if nargout==2;
      DiffField = 'StateScenarioShocks';
   end;
   return;
end;
if (length(DSGEModel.StateScenarioVariables)~=length(OrigDSGEModel.StateScenarioVariables))|(max(abs(DSGEModel.StateScenarioVariables-OrigDSGEModel.StateScenarioVariables))>0);
   if nargout==2;
      DiffField = 'StateScenarioVariables';
   end;
   return;
end;
if (length(DSGEModel.ConstrainedStateVariables)~=length(OrigDSGEModel.ConstrainedStateVariables))|(max(abs(DSGEModel.ConstrainedStateVariables-OrigDSGEModel.ConstrainedStateVariables))>0);
   if nargout==2;
      DiffField = 'ConstrainedStateVariables';
   end;
   return;
end;
if (isequal(DSGEModel.ObsVarGroupNames,OrigDSGEModel.ObsVarGroupNames)==0)|(length(DSGEModel.ObsVarGroups)~=length(OrigDSGEModel.ObsVarGroups))|(sum(abs(DSGEModel.ObsVarGroups-OrigDSGEModel.ObsVarGroups))>0);
   if nargout==2;
      DiffField = 'ObsVarGroupNames';
   end;
   return;
end;
if (size(DSGEModel.ObsVarGroupColors,1)~=size(OrigDSGEModel.ObsVarGroupColors,1))|(max(max(abs(DSGEModel.ObsVarGroupColors-OrigDSGEModel.ObsVarGroupColors)))>0);
   if nargout==2;
      DiffField = 'ObsVarGroupColors';
   end;
   return;
end;
if abs(DSGEModel.PosteriorSampler-OrigDSGEModel.PosteriorSampler)>0
   if nargout==2;
      DiffField = 'PosteriorSampler';
   end;
   return;
end;
if isequal(DSGEModel.StudenttDegFree,OrigDSGEModel.StudenttDegFree)==0;
   if nargout==2;
      DiffField = 'StudenttDegFree';
   end;
   return;
end;
if isequal(DSGEModel.FixedNumParamBlocks,OrigDSGEModel.FixedNumParamBlocks)==0;
   if nargout==2;
      DiffField = 'FixedNumParamBlocks';
   end;
   return;
end;
if isequal(DSGEModel.BlockSize,OrigDSGEModel.BlockSize)==0;
   if nargout==2;
      DiffField = 'BlockSize';
   end;
   return;
end;
if abs(DSGEModel.ModelSolver-OrigDSGEModel.ModelSolver)>0;
   if nargout==2;
      DiffField = 'ModelSolver';
   end;
   return;
end;
if abs(DSGEModel.KalmanAlgorithm-OrigDSGEModel.KalmanAlgorithm)>0;
   if nargout==2;
      DiffField = 'KalmanAlgorithm';
   end;
   return;
end;
if abs(DSGEModel.CsminwelExtraRuns-OrigDSGEModel.CsminwelExtraRuns)>0;
   if nargout==2;
      DiffField = 'CsminwelExtraRuns';
   end;
   return;
end;
if abs(DSGEModel.MonteCarloFilterDraws-OrigDSGEModel.MonteCarloFilterDraws)>0;
   if nargout==2;
      DiffField = 'MonteCarloFilterDraws';
   end;
   return;
end;
if abs(DSGEModel.MonteCarloFilterDrawsAL-OrigDSGEModel.MonteCarloFilterDrawsAL)>0;
   if nargout==2;
      DiffField = 'MonteCarloFilterDrawsAL';
   end;
   return;
end;
if abs(DSGEModel.StationaryVAR-OrigDSGEModel.StationaryVAR)>0;
   if nargout==2;
      DiffField = 'StationaryVAR';
   end;
   return;
end;
if isequal(DSGEModel.PredictionVariables,OrigDSGEModel.PredictionVariables)==0;
   if nargout==2;
      DiffField = 'PredictionVariables';
   end;
   return;
end;
if abs(DSGEModel.ConfidenceRegionMethod-OrigDSGEModel.ConfidenceRegionMethod)>0;
   if nargout==2;
      DiffField = 'ConfidenceRegionMethod';
   end;
   return;
end;
if isequal(DSGEModel.RtildePosition,OrigDSGEModel.RtildePosition)==0;
   if nargout==2;
      DiffField = 'RtildePosition';
   end;
   return;
end;
if isequal(DSGEModel.REqPosition,OrigDSGEModel.REqPosition)==0;
   if nargout==2;
      DiffField = 'REqPosition';
   end;
   return;
end;
if isequal(DSGEModel.ZLBSampleT,OrigDSGEModel.ZLBSampleT)==0;
   if nargout==2;
      DiffField = 'ZLBSampleT';
   end;
   return;
end;
if isequal(DSGEModel.TargetVariablePosition,OrigDSGEModel.TargetVariablePosition)==0;
   if nargout==2;
      DiffField = 'TargetVariablePosition';
   end;
   return;
end;
if isequal(DSGEModel.TargetEqPosition,OrigDSGEModel.TargetEqPosition)==0;
   if nargout==2;
      DiffField = 'TargetEqPosition';
   end;
   return;
end;
if isequal(DSGEModel.TargetShockValue,OrigDSGEModel.TargetShockValue)==0;
   if nargout==2;
      DiffField = 'TargetShockValue';
   end;
   return;
end;
% ResponseDenominatorPosition
if isequal(DSGEModel.ResponseDenominatorPosition,OrigDSGEModel.ResponseDenominatorPosition)==0;
   if nargout==2;
      DiffField = 'ResponseDenominatorPosition';
   end;
   return;
end;
% TemperingStagesValue
if isequal(DSGEModel.TemperingStagesValue,OrigDSGEModel.TemperingStagesValue)==0;
   if nargout==2;
      DiffField = 'TemperingStagesValue';
   end;
   return;
end;
% TemperingLambdaValue
if isequal(DSGEModel.TemperingLambdaValue,OrigDSGEModel.TemperingLambdaValue)==0;
   if nargout==2;
      DiffField = 'TemperingLambdaValue';
   end;
   return;
end;
% NumParamBlocks
if isequal(DSGEModel.NumParamBlocks,OrigDSGEModel.NumParamBlocks)==0;
   if nargout==2;
      DiffField = 'NumParamBlocks';
   end;
   return;
end;
% MixedDistWeightValue
if isequal(DSGEModel.MixedDistWeightValue,OrigDSGEModel.MixedDistWeightValue)==0;
   if nargout==2;
      DiffField = 'MixedDistWeightValue';
   end;
   return;
end;
% SMCInitialScaleFactor
if isequal(DSGEModel.SMCInitialScaleFactor,OrigDSGEModel.SMCInitialScaleFactor)==0;
   if nargout==2;
      DiffField = 'SMCInitialScaleFactor';
   end;
   return;
end;
% TargetAcceptanceRateValue
if isequal(DSGEModel.TargetAcceptanceRateValue,OrigDSGEModel.TargetAcceptanceRateValue)==0;
   if nargout==2;
      DiffField = 'TargetAcceptanceRateValue';
   end;
   return;
end;
% ResamplingAlgorithm
if isequal(DSGEModel.ResamplingAlgorithm,OrigDSGEModel.ResamplingAlgorithm)==0;
   if nargout==2;
      DiffField = 'ResamplingAlgorithm';
   end;
   return;
end;
% SMCNumMHSteps
if isequal(DSGEModel.SMCNumMHSteps,OrigDSGEModel.SMCNumMHSteps)==0;
   if nargout==2;
      DiffField = 'SMCNumMHSteps';
   end;
   return;
end;
% ResamplingThresholdValue
if isequal(DSGEModel.ResamplingThresholdValue,OrigDSGEModel.ResamplingThresholdValue)==0;
   if nargout==2;
      DiffField = 'ResamplingThresholdValue';
   end;
   return;
end;
% ISMaxMixCompValue
if isequal(DSGEModel.ISMaxMixCompValue,OrigDSGEModel.ISMaxMixCompValue)==0;
   if nargout==2;
      DiffField = 'ISMaxMixCompValue';
   end;
   return;
end;
% ISInitialDF
if isequal(DSGEModel.ISInitialDF,OrigDSGEModel.ISInitialDF)==0;
   if nargout==2;
      DiffField = 'ISInitialDF';
   end;
   return;
end;
% ISWeightShareValue
if isequal(DSGEModel.ISWeightShareValue,OrigDSGEModel.ISWeightShareValue)==0;
   if nargout==2;
      DiffField = 'ISWeightShareValue';
   end;
   return;
end;
% ISAddedMixWeightValue
if isequal(DSGEModel.ISAddedMixWeightValue,OrigDSGEModel.ISAddedMixWeightValue)==0;
   if nargout==2;
      DiffField = 'ISAddedMixWeightValue';
   end;
   return;
end;
% ISAddedDF
if isequal(DSGEModel.ISAddedDF,OrigDSGEModel.ISAddedDF)==0;
   if nargout==2;
      DiffField = 'ISAddedDF';
   end;
   return;
end;
% CoVToleranceValue
if isequal(DSGEModel.CoVToleranceValue,OrigDSGEModel.CoVToleranceValue)==0;
   if nargout==2;
      DiffField = 'CoVToleranceValue';
   end;
   return;
end;
% ForwardVariableNames and ForwardVariablePositions
if (isequal(DSGEModel.ForwardVariableNames,OrigDSGEModel.ForwardVariableNames)==0)|(length(DSGEModel.ForwardVariablePositions)~=length(OrigDSGEModel.ForwardVariablePositions))|(sum(abs(DSGEModel.ForwardVariablePositions-OrigDSGEModel.ForwardVariablePositions))>0);
   if nargout==2;
      DiffField = 'ForwardVariableNames';
   end;
   return;
end;
% BeliefSystem
if isequal(DSGEModel.BeliefSystem,OrigDSGEModel.BeliefSystem)==0;
   if nargout==2;
      DiffField = 'BeliefSystem';
   end;
   return;
end;
% BeliefSystemFile
if strcmp(lower(DSGEModel.BeliefSystemFile),lower(OrigDSGEModel.BeliefSystemFile))==0;
   if nargout==2;
      DiffField = 'BeliefSystemFile';
   end;
   return;
end;
% BeliefPriorFile
if strcmp(lower(DSGEModel.BeliefPriorFile),lower(OrigDSGEModel.BeliefPriorFile))==0;
   if nargout==2;
      DiffField = 'BeliefPriorFile';
   end;
   return;
end;
% BeliefPriorFileSheet
if strcmp(lower(DSGEModel.BeliefPriorFileSheet),lower(OrigDSGEModel.BeliefPriorFileSheet))==0;
   if nargout==2;
      DiffField = 'BeliefPriorFileSheet';
   end;
   return;
end;
% NoSmoothedStatesForBeliefs
if isequal(DSGEModel.NoSmoothedStatesForBeliefs,OrigDSGEModel.NoSmoothedStatesForBeliefs)==0;
   if nargout==2;
      DiffField = 'NoSmoothedStatesForBeliefs';
   end;
   return;
end;
% FixedBeliefsForProj
if isequal(DSGEModel.FixedBeliefsForProj,OrigDSGEModel.FixedBeliefsForProj)==0;
   if nargout==2;
      DiffField = 'FixedBeliefsForProj';
   end;
   return;
end;
if strcmp(lower(DSGEModel.AdaptiveLearningModelSolverFile),lower(OrigDSGEModel.AdaptiveLearningModelSolverFile))==0;
   if nargout==2;
      DiffField = 'AdaptiveLearningModelSolverFile';
   end;
   return;
end;
if strcmp(lower(DSGEModel.DSGEImportIVFile),lower(OrigDSGEModel.DSGEImportIVFile))==0;
   if nargout==2;
      DiffField = 'DSGEImportIVFile';
   end;
   return;
end;
if strcmp(lower(DSGEModel.ALDSGEImportIVFile),lower(OrigDSGEModel.ALDSGEImportIVFile))==0;
   if nargout==2;
      DiffField = 'ALDSGEImportIVFile';
   end;
   return;
end;
if strcmp(lower(DSGEModel.DSGEVARMargImportIVFile),lower(OrigDSGEModel.DSGEVARMargImportIVFile))==0;
   if nargout==2;
      DiffField = 'DSGEVARMargImportIVFile';
   end;
   return;
end;
if strcmp(lower(DSGEModel.DSGEVARImportIVFile),lower(OrigDSGEModel.DSGEVARImportIVFile))==0;
   if nargout==2;
      DiffField = 'DSGEVARImportIVFile';
   end;
   return;
end;
if isequal(DSGEModel.ShowEstimationLog,OrigDSGEModel.ShowEstimationLog)==0;
   if nargout==2;
      DiffField = 'ShowEstimationLog';
   end;
   return;
end;
if strcmp(lower(DSGEModel.DynareModelFile),lower(OrigDSGEModel.DynareModelFile))==0;
   if nargout==2;
      DiffField = 'DynareModelFile';
   end;
   return;
end;
if strcmp(lower(DSGEModel.DriverFunctions),lower(OrigDSGEModel.DriverFunctions))==0;
   if nargout==2;
      DiffField = 'DriverFunctions';
   end;
   return;
end;
if strcmp(lower(DSGEModel.RunScriptFile),lower(OrigDSGEModel.RunScriptFile))==0;
   if nargout==2;
      DiffField = 'RunScriptFile';
   end;
   return;
end;
if isequal(DSGEModel.ZLBRuleType,OrigDSGEModel.ZLBRuleType)==0;
   if nargout==2;
      DiffField = 'ZLBRuleType';
   end;
   return;
end;
%
% there were no differences!
%
status = 1;

%
% end of CompareDSGEModel.m
%
