function controls = ToolsMenuControls(maingui,controls)
% ToolsMenuControls: sets up the Tools menu.
%
% USAGE:
%
%       controls = ToolsMenuControls(maingui,controls)
%
% REQUIRED INPUT:  maingui (handle) to YADA's main dialog.
%
%                  controls (structure) with handles to the controls on the YADA main dialog.
%
% REQUIRED OUTPUT: controls (structure) with handles to the controls on the YADA main dialog.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   Forecasting and Policy Modelling Division
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2025 European Central Bank.
%
%                       First version: March 3, 2010.
%                        This version: January 9, 2025.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 04-03-2010: Updated the documentation.
%
% * 05-05-2010: Added controls for computing the information matrix from a frequency domain
%               perspective.
%
% * 09-05-2010: Added controls for computing the coherence statistic.
%
% * 10-05-2010: Took into account that the "ToolsMenuFunction" has been split into several parts
%               in order to speed up case loadings.
%
% * 21-06-2010: Updated the documentation.
%
% * 05-01-2011: Updated the documentation.
%
% * 12-01-2011: The function now supports unix and mac paths.
%
% * 17-01-2011: Added controls for "Correlation decompositions".
%
% * 14-12-2011: Added controls for "Monte Carlo Filtering".
%
% * 02-01-2012: Updated the documentation.
%
% * 20-03-2012: Added controls for the height of the predictive density.
%
% * 29-03-2012: Changed the label from "Predictive Density Height" to "Predictive Likelihood".
%
% * 07-05-2012: Added controls for the predictive likelihood under annualization.
%
% * 03-01-2013: Updated the documentation.
%
% * 17-07-2013: Added all the controls for conditional forecasting with restrictions on state
%               variables.
%
% * 13-08-2013: Added controls for predictive checks of the one-step-ahead forecasts errors.
%
% * 28-01-2014: Updated the documentation.
%
% * 20-03-2014: Added controls for the parameter change effects on the observed variable moments.
%
% * 18-08-2014: Added controls for calculating conditional forecasts subject to the zero lower
%               bound.
%
% * 17-12-2014: Added controls for computing the impulse responses of state variables using the
%               prior and the posterior draws.
%
% * 14-01-2015: Updated the documentation.
%
% * 08-09-2015: Initialized fields of the controls structure that are subfield, but that don't contain
%               any handles by themselves. This is necessary since Matlab 2014b.
%
% * 27-01-2016: Remember Shoah.
%
% * 21-03-2017: Updated the documentation.
%
% * 03-05-2017: Added controls for state variable conditional variance decompositions.
%
% * 20-06-2017: Added controls for the marginal predictive moments for the original data using prior
%               and posterior draws.
%
% * 15-09-2017: Updated the documentation.
%
% * 15-12-2017: Added controls for variance decompositions for the state variables.
%
% * 08-01-2018: Updated the documentation.
%
% * 23-01-2019: Updated the documentation.
%
% * 21-03-2019: Added controls for computing the forecast error variance decompositions of the stationary
%               predictive distribution into state, shock, measurement error and parameter uncertainty using
%               the prior or the posterior draws.
%
% * 27-03-2019: Updated the documentation.
%
% * 15-04-2019: Added controls for computing parameter change effects on the moments of state variables.
%
% * 10-01-2020: Updated the documentation.
%
% * 25-08-2020: Added controls for the probability integral transform.
%
% * 28-08-2020: Added controls for the continuous ranked probability score.
%
% * 26-01-2021: Updated the documentation.
%
% * 06-01-2022: Updated the documentation.
%
% * 24-08-2022: Added controls for unconditional forecasts subject to the ZLB under the initial
%               values and the posterior mode values.
%
% * 26-08-2022: Added controls for unconditional forecasts subject to the ZLB using the posterior draws.
%
% * 05-10-2022: Added controls for unconditional forecasts subject to the ZLB using the prior draws.
%
% * 07-12-2022: Commented out the ZLB handles for conditional forecasts.
%
% * 05-01-2023: Updated the documentation.
%
% * 23-02-2023: Reinstated the ZLB handles for conditional forecasts at posterior mode.
%
% * 14-03-2023: Reinstated the ZLB handles for conditional forecasts at the initial values.
%
% * 16-03-2023: Added controls for prior and posterior distribution for conditional forecasts
%               subject to the ZLB.
%
% * 10-05-2023: Added control for viewing the actuals data.
%
% * 25-07-2023: Added controls for computing the observation weights decompositions of the
%               unconditional forecasts at initial values and at posterior mode.
%
% * 11-12-2023: Added controls for observed variable decompositions using prior and posterior
%               draws of the parameters.
%
% * 12-12-2023: Took into account that the name of the function computing obs var decompositions
%               for prior draws has changed.
%
% * 02-01-2024: Added controls for CRPS and ES using the conditional forecasts.
%
% * 16-01-2024: Added controls for CRPS and ES using unconditional forecasts subject to the ZLB.
%
% * 29-01-2024: Added controls for predictive likelihood using unconditional forecasts subject
%               to the ZLB.
%
% * 06-02-2024: Added controls for predictive likelihood using conditional forecasts subject
%               to the ZLB.
%
% * 07-02-2024: Added controls for CRPS and ES calculations using conditional forecasts subject
%               to the ZLB. Also added controls for predictive likelihood calculations using
%               conditional forecasts subject to the ZLB.
%
% * 29-07-2024: Added controls for the marginal predictive moments using conditional forecasts.
%
% * 31-07-2024: Added controls for the PIT using the conditional forecasts.
%
% * 21-08-2024: Added controls for the parameter change functions for the IRFs.
%
% * 09-01-2025: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% Tools menu
%
controls.toolsmenu = uimenu('Parent',maingui, ...
   'Label','&Tools', ...
   'Tag','ToolsMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                    Display eigenvalues of the DSGE model                    %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.dsgeeigenvalues.parent = uimenu('Parent',controls.toolsmenu, ...
   'Label','DS&GE Model Eigenvalues', ...
   'Enable','on', ...
   'Tag','ViewDSGEEigenvaluesMenu');
%
controls.dsgeeigenvalues.initialvalues = uimenu('Parent',controls.dsgeeigenvalues.parent, ...
   'Label','&Initial Values...', ...
   'Callback','ToolsMenuFunctions DSGEEigenvaluesInitialValues', ...
   'Enable','off', ...
   'Tag','DSGEEigenvaluesInitialValuesMenu');
%
controls.dsgeeigenvalues.postmode = uimenu('Parent',controls.dsgeeigenvalues.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','ToolsMenuFunctions DSGEEigenvaluesPostMode', ...
   'Enable','off', ...
   'Tag','DSGEEigenvaluesPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                            Monte Carlo Filtering                            %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.montecarlofiltering = uimenu('Parent',controls.toolsmenu, ...
   'Label','Monte Carlo &Filtering...', ...
   'Callback','ToolsMenuFunctions MonteCarloFiltering', ...
   'Enable','off', ...
   'Tag','MonteCarloFilteringMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%       Check invertibility condition of the DSGE model relative to an        %
%                             infinite order VAR                              %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.dsgetovareigenvalues.parent = uimenu('Parent',controls.toolsmenu, ...
   'Label','Poor Man''s Invertibilit&y Condition', ...
   'Enable','on', ...
   'Tag','ViewDSGEtoVAREigenvaluesMenu');
%
controls.dsgetovareigenvalues.initialvalues = uimenu('Parent',controls.dsgetovareigenvalues.parent, ...
   'Label','&Initial Values...', ...
   'Callback','ToolsMenuFunctions PoorManInverseInitialValues', ...
   'Enable','off', ...
   'Tag','DSGEtoVAREigenvaluesInitialValuesMenu');
%
controls.dsgetovareigenvalues.postmode = uimenu('Parent',controls.dsgetovareigenvalues.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','ToolsMenuFunctions PoorManInversePostMode', ...
   'Enable','off', ...
   'Tag','DSGEtoVAREigenvaluesPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                        check the information matrix                         %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.informationmatrix.parent = uimenu('Parent',controls.toolsmenu, ...
   'Label','Information Matri&x', ...
   'Enable','on', ...
   'Tag','InformationMatrixMenu');
%
% frequency domain
%
controls.informationmatrix.frequencydomain.parent = uimenu('Parent',controls.informationmatrix.parent, ...
   'Label','&Frequency Domain', ...
   'Enable','on', ...
   'Tag','InformationMatrixFrequencyDomainMenu');
%
% initial values
%
controls.informationmatrix.frequencydomain.initialvalues = uimenu('Parent',controls.informationmatrix.frequencydomain.parent, ...
   'Label','&Initial Values...', ...
   'Callback','ToolsMenuFunctions InfMatFreqDomainInitialValues', ...
   'Enable','off', ...
   'Tag','InformationMatrixFrequencyDomainInitialValuesMenu');
%
% posterior mode values
%
controls.informationmatrix.frequencydomain.postmode = uimenu('Parent',controls.informationmatrix.frequencydomain.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','ToolsMenuFunctions InfMatFreqDomainPostMode', ...
   'Enable','off', ...
   'Tag','InformationMatrixFrequencyDomainPosteriorModeMenu');
%
% time domain
%
controls.informationmatrix.timedomain.parent = uimenu('Parent',controls.informationmatrix.parent, ...
   'Label','&Time Domain', ...
   'Enable','on', ...
   'Tag','InformationMatrixTimeDomainMenu');
%
% initial values
%
controls.informationmatrix.timedomain.initialvalues = uimenu('Parent',controls.informationmatrix.timedomain.parent, ...
   'Label','&Initial Values...', ...
   'Callback','ToolsMenuFunctions InfMatTimeDomainInitialValues', ...
   'Enable','off', ...
   'Tag','InformationMatrixTimeDomainInitialValuesMenu');
%
% posterior mode values
%
controls.informationmatrix.timedomain.postmode = uimenu('Parent',controls.informationmatrix.timedomain.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','ToolsMenuFunctions InfMatTimeDomainPostMode', ...
   'Enable','off', ...
   'Tag','InformationMatrixTimeDomainPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                                Simulate data                                %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.simulatedata.parent = uimenu('Parent',controls.toolsmenu, ...
   'Label','Sim&ulate Data', ...
   'Separator','on', ...
   'Enable','on', ...
   'Tag','SimulateDataMenu');
%
controls.simulatedata.initialvalues = uimenu('Parent',controls.simulatedata.parent, ...
   'Label','&Initial Values...', ...
   'Callback','ToolsMenuFunctions DSGESimulateDataInitialValues', ...
   'Enable','off', ...
   'Tag','SimulateDataInitialValuesMenu');
%
controls.simulatedata.postmode = uimenu('Parent',controls.simulatedata.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','ToolsMenuFunctions DSGESimulateDataPostMode', ...
   'Enable','off', ...
   'Tag','SimulateDataPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                   Display observed variable correlations                    %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.obsvarcorrs.parent = uimenu('Parent',controls.toolsmenu, ...
   'Separator','on', ...
   'Label','&Observed Variable Correlations', ...
   'Tag','ObsVariableCorrelationsMenu');
%
% frequency domain
%
controls.obsvarcorrs.frequencydomain.parent = uimenu('Parent',controls.obsvarcorrs.parent, ...
   'Label','&Frequency Domain', ...
   'Tag','ObsVariableCoherenceMenu');
%
controls.obsvarcorrs.frequencydomain.initialvalues = uimenu('Parent',controls.obsvarcorrs.frequencydomain.parent, ...
   'Label','&Initial Values...', ...
   'Callback','CorrToolsMenuFunctions CoherenceInitialValues', ...
   'Enable','off', ...
   'Tag','ObsVariableCoherenceInitialValuesMenu');
%
controls.obsvarcorrs.frequencydomain.prior = uimenu('Parent',controls.obsvarcorrs.frequencydomain.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','CorrToolsMenuFunctions CoherencePriorDist', ...
   'Enable','off', ...
   'Tag','ObsVariableCoherencePriorDistMenu');
%
controls.obsvarcorrs.frequencydomain.postmode = uimenu('Parent',controls.obsvarcorrs.frequencydomain.parent, ...
   'Label','&Posterior Mode...', ...
   'Separator','on', ...
   'Callback','CorrToolsMenuFunctions CoherencePostMode', ...
   'Enable','off', ...
   'Tag','ObsVariableCoherencePosteriorModeMenu');
%
controls.obsvarcorrs.frequencydomain.posterior = uimenu('Parent',controls.obsvarcorrs.frequencydomain.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','CorrToolsMenuFunctions CoherencePosteriorDist', ...
   'Enable','off', ...
   'Tag','ObsVariableCoherenceDistMenu');
%
% time domain
%
controls.obsvarcorrs.timedomain.parent = uimenu('Parent',controls.obsvarcorrs.parent, ...
   'Label','&Time Domain', ...
   'Tag','ObsVariableTimeCorrelationsMenu');
%
controls.obsvarcorrs.timedomain.initialvalues = uimenu('Parent',controls.obsvarcorrs.timedomain.parent, ...
   'Label','&Initial Values...', ...
   'Callback','CorrToolsMenuFunctions ObsVarCorrInitialValues', ...
   'Enable','off', ...
   'Tag','ObsVariableCorrelationsInitialValuesMenu');
%
controls.obsvarcorrs.timedomain.prior = uimenu('Parent',controls.obsvarcorrs.timedomain.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','CorrToolsMenuFunctions ObsVarCorrPriorDist', ...
   'Enable','off', ...
   'Tag','ObsVariableCorrelationsPriorDistMenu');
%
controls.obsvarcorrs.timedomain.postmode = uimenu('Parent',controls.obsvarcorrs.timedomain.parent, ...
   'Label','&Posterior Mode...', ...
   'Separator','on', ...
   'Callback','CorrToolsMenuFunctions ObsVarCorrPostMode', ...
   'Enable','off', ...
   'Tag','ObsVariableCorrelationsPosteriorModeMenu');
%
controls.obsvarcorrs.timedomain.posterior = uimenu('Parent',controls.obsvarcorrs.timedomain.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','CorrToolsMenuFunctions ObsVarCorrPosteriorDist', ...
   'Enable','off', ...
   'Tag','ObsVariableCorrelationsDistMenu');
%
% parameter changes
%
controls.obsvarcorrs.parameterchange.parent = uimenu('Parent',controls.obsvarcorrs.parent, ...
   'Label','&Parameter Change', ...
   'Separator','on', ...
   'Tag','ObsVariableCorrelationParameterChangeMenu');
%
controls.obsvarcorrs.parameterchange.initialvalues = uimenu('Parent',controls.obsvarcorrs.parameterchange.parent, ...
   'Label','&Initial Values...', ...
   'Callback','CorrToolsMenuFunctions ObsVarCorrParameterChangeInitVal', ...
   'Enable','off', ...
   'Tag','ObsVariableCorrParameterChangeInitialValuesMenu');
%
controls.obsvarcorrs.parameterchange.prior = uimenu('Parent',controls.obsvarcorrs.parameterchange.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','CorrToolsMenuFunctions ObsVarCorrParameterChangePriorDist', ...
   'Enable','off', ...
   'Tag','ObsVariableCorrParameterChangePriorDistMenu');
%
controls.obsvarcorrs.parameterchange.postmode = uimenu('Parent',controls.obsvarcorrs.parameterchange.parent, ...
   'Label','&Posterior Mode...', ...
   'Separator','on', ...
   'Callback','CorrToolsMenuFunctions ObsVarCorrParameterChangePostMode', ...
   'Enable','off', ...
   'Tag','ObsVariableCorrParameterChangePosteriorModeMenu');
%
controls.obsvarcorrs.parameterchange.posterior = uimenu('Parent',controls.obsvarcorrs.parameterchange.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','CorrToolsMenuFunctions ObsVarCorrParameterChangePosteriorDist', ...
   'Enable','off', ...
   'Tag','ObsVariableCorrParameterChangePosteriorDistMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                      Display conditional correlations                       %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.condcorrs.parent = uimenu('Parent',controls.toolsmenu, ...
   'Label','Conditional Co&rrelations', ...
   'Tag','ConditionalCorrelationsMenu');
%
controls.condcorrs.initialvalues = uimenu('Parent',controls.condcorrs.parent, ...
   'Label','&Initial Values...', ...
   'Callback','CorrToolsMenuFunctions CondCorrInitialValues', ...
   'Enable','off', ...
   'Tag','ConditionalCorrelationsInitialValuesMenu');
%
controls.condcorrs.prior = uimenu('Parent',controls.condcorrs.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','CorrToolsMenuFunctions CondCorrPriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalCorrelationsPriorDistMenu');
%
controls.condcorrs.postmode = uimenu('Parent',controls.condcorrs.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','CorrToolsMenuFunctions CondCorrPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalCorrelationsPosteriorModeMenu');
%
controls.condcorrs.posterior = uimenu('Parent',controls.condcorrs.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','CorrToolsMenuFunctions CondCorrPosteriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalCorrelationsDistMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                     Display state variable correlations                     %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.statevarcorrs.parent = uimenu('Parent',controls.toolsmenu, ...
   'Label','State Variable &Correlations', ...
   'Tag','StateVariableCorrelationsMenu');
%
% frequency domain
%
controls.statevarcorrs.frequencydomain.parent = uimenu('Parent',controls.statevarcorrs.parent, ...
   'Label','&Frequency Domain', ...
   'Tag','StateVariableCoherenceMenu');
%
controls.statevarcorrs.frequencydomain.initialvalues = uimenu('Parent',controls.statevarcorrs.frequencydomain.parent, ...
   'Label','&Initial Values...', ...
   'Callback','CorrToolsMenuFunctions CoherenceInitialValues', ...
   'Enable','off', ...
   'Tag','StateVariableCoherenceInitialValuesMenu');
%
controls.statevarcorrs.frequencydomain.prior = uimenu('Parent',controls.statevarcorrs.frequencydomain.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','CorrToolsMenuFunctions CoherencePriorDist', ...
   'Enable','off', ...
   'Tag','StateVariableCoherencePriorDistMenu');
%
controls.statevarcorrs.frequencydomain.postmode = uimenu('Parent',controls.statevarcorrs.frequencydomain.parent, ...
   'Label','&Posterior Mode...', ...
   'Separator','on', ...
   'Callback','CorrToolsMenuFunctions CoherencePostMode', ...
   'Enable','off', ...
   'Tag','StateVariableCoherencePosteriorModeMenu');
%
controls.statevarcorrs.frequencydomain.posterior = uimenu('Parent',controls.statevarcorrs.frequencydomain.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','CorrToolsMenuFunctions CoherencePosteriorDist', ...
   'Enable','off', ...
   'Tag','StateVariableCoherenceDistMenu');
%
% time domain
%
controls.statevarcorrs.timedomain.parent = uimenu('Parent',controls.statevarcorrs.parent, ...
   'Label','&Time Domain', ...
   'Tag','StateVariableCorrelationsMenu');
%
controls.statevarcorrs.timedomain.initialvalues = uimenu('Parent',controls.statevarcorrs.timedomain.parent, ...
   'Label','&Initial Values...', ...
   'Callback','CorrToolsMenuFunctions StateVarCorrInitialValues', ...
   'Enable','off', ...
   'Tag','StateVariableCorrelationsInitialValuesMenu');
%
controls.statevarcorrs.timedomain.prior = uimenu('Parent',controls.statevarcorrs.timedomain.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','CorrToolsMenuFunctions StateVarCorrPriorDist', ...
   'Enable','off', ...
   'Tag','StateVariableCorrelationsPriorDistMenu');
%
controls.statevarcorrs.timedomain.postmode = uimenu('Parent',controls.statevarcorrs.timedomain.parent, ...
   'Label','&Posterior Mode...', ...
   'Separator','on', ...
   'Callback','CorrToolsMenuFunctions StateVarCorrPostMode', ...
   'Enable','off', ...
   'Tag','StateVariableCorrelationsPosteriorModeMenu');
%
controls.statevarcorrs.timedomain.posterior = uimenu('Parent',controls.statevarcorrs.timedomain.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','CorrToolsMenuFunctions StateVarCorrPosteriorDist', ...
   'Enable','off', ...
   'Tag','StateVariableCorrelationsDistMenu');
%
% parameter changes
%
controls.statevarcorrs.parameterchange.parent = uimenu('Parent',controls.statevarcorrs.parent, ...
   'Label','&Parameter Change', ...
   'Separator','on', ...
   'Tag','StateVariableCorrelationParameterChangeMenu');
%
controls.statevarcorrs.parameterchange.initialvalues = uimenu('Parent',controls.statevarcorrs.parameterchange.parent, ...
   'Label','&Initial Values...', ...
   'Callback','CorrToolsMenuFunctions StateVarCorrParameterChangeInitVal', ...
   'Enable','off', ...
   'Tag','StateVariableCorrParameterChangeInitialValuesMenu');
%
controls.statevarcorrs.parameterchange.prior = uimenu('Parent',controls.statevarcorrs.parameterchange.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','CorrToolsMenuFunctions StateVarCorrParameterChangePriorDist', ...
   'Enable','off', ...
   'Tag','StateVariableCorrParameterChangePriorDistMenu');
%
controls.statevarcorrs.parameterchange.postmode = uimenu('Parent',controls.statevarcorrs.parameterchange.parent, ...
   'Label','&Posterior Mode...', ...
   'Separator','on', ...
   'Callback','CorrToolsMenuFunctions StateVarCorrParameterChangePostMode', ...
   'Enable','off', ...
   'Tag','StateVariableCorrParameterChangePosteriorModeMenu');
%
controls.statevarcorrs.parameterchange.posterior = uimenu('Parent',controls.statevarcorrs.parameterchange.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','CorrToolsMenuFunctions StateVarCorrParameterChangePosteriorDist', ...
   'Enable','off', ...
   'Tag','StateVariableCorrParameterChangePosteriorDistMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                      Displays state shock correlations                      %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.stateshockcorrs.parent = uimenu('Parent',controls.toolsmenu, ...
   'Label','S&tate Shock Correlations', ...
   'Tag','StateShockCorrelationsMenu');
%
controls.stateshockcorrs.initialvalues = uimenu('Parent',controls.stateshockcorrs.parent, ...
   'Label','&Initial Values...', ...
   'Callback','CorrToolsMenuFunctions ShockCorrInitialValues', ...
   'Enable','off', ...
   'Tag','StateShockCorrelationsInitialValuesMenu');
%
controls.stateshockcorrs.prior = uimenu('Parent',controls.stateshockcorrs.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','CorrToolsMenuFunctions ShockCorrPriorDist', ...
   'Enable','off', ...
   'Tag','StateShockCorrelationsPriorDistMenu');
%
controls.stateshockcorrs.postmode = uimenu('Parent',controls.stateshockcorrs.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','CorrToolsMenuFunctions ShockCorrPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','StateShockCorrelationsPosteriorModeMenu');
%
controls.stateshockcorrs.posterior = uimenu('Parent',controls.stateshockcorrs.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','CorrToolsMenuFunctions ShockCorrPosteriorDist', ...
   'Enable','off', ...
   'Tag','StateShockCorrelationsDistMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                   Displays measurement error correlations                   %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.measurementerrorcorrs.parent = uimenu('Parent',controls.toolsmenu, ...
   'Label','Me&asurement Error Correlations', ...
   'Tag','MeasurementErrorCorrelationsMenu');
%
controls.measurementerrorcorrs.initialvalues = uimenu('Parent',controls.measurementerrorcorrs.parent, ...
   'Label','&Initial Values...', ...
   'Callback','CorrToolsMenuFunctions MECorrInitialValues', ...
   'Enable','off', ...
   'Tag','MeasurementErrorCorrelationsInitialValuesMenu');
%
controls.measurementerrorcorrs.prior = uimenu('Parent',controls.measurementerrorcorrs.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','CorrToolsMenuFunctions MECorrPriorDist', ...
   'Enable','off', ...
   'Tag','MeasurementErrorCorrelationsPriorDistMenu');
%
controls.measurementerrorcorrs.postmode = uimenu('Parent',controls.measurementerrorcorrs.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','CorrToolsMenuFunctions MECorrPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','MeasurementErrorCorrelationsPosteriorModeMenu');
%
controls.measurementerrorcorrs.posterior = uimenu('Parent',controls.measurementerrorcorrs.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','CorrToolsMenuFunctions MECorrPosteriorDist', ...
   'Enable','off', ...
   'Tag','MeasurementErrorCorrelationsDistMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                    Graph forecasts of observed variables                    %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.obsvar.parent = uimenu('Parent',controls.toolsmenu, ...
   'Label','&1-Step Ahead Forecasts', ...
   'Separator','on', ...
   'Tag','ObsVariablesForecast1Menu');
%
% predictive checks
%
controls.obsvar.predchecks.parent = uimenu('Parent',controls.obsvar.parent, ...
   'Label','Predictive &Checks', ...
   'Tag','OneStepAheadPredCheckMenu');
%
% prior predictive check for one-step-ahead forecast errors
%
controls.obsvar.predchecks.prior = uimenu('Parent',controls.obsvar.predchecks.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','CorrToolsMenuFunctions OneStepAheadPredCheckPriorDist', ...
   'Enable','off', ...
   'Tag','OneStepAheadPredCheckPriorDistMenu');
%
% posterior predictive check for one-step-ahead forecast errors
%
controls.obsvar.predchecks.posterior = uimenu('Parent',controls.obsvar.predchecks.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','CorrToolsMenuFunctions OneStepAheadPredCheckPosteriorDist', ...
   'Enable','off', ...
   'Tag','OneStepAheadPredCheckPosteriorDistMenu');
%
% Initial values
%
controls.obsvar.initialvalues = uimenu('Parent',controls.obsvar.parent, ...
   'Label','&Initial Values...', ...
   'Callback','ToolsMenuFunctions OSAForecastInitialValues', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ObsVariablesForecast1InitialValuesMenu');
%
controls.obsvar.prior = uimenu('Parent',controls.obsvar.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','ToolsMenuFunctions OSAForecastPriorDist', ...
   'Enable','off', ...
   'Tag','ObsVariablesForecast1PriorDistMenu');
%
% Posterior mode
%
controls.obsvar.postmode = uimenu('Parent',controls.obsvar.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','ToolsMenuFunctions OSAForecastPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ObsVariablesForecast1PosteriorModeMenu');
%
controls.obsvar.posterior = uimenu('Parent',controls.obsvar.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ToolsMenuFunctions OSAForecastPosteriorDist', ...
   'Enable','off', ...
   'Tag','ObsVariablesForecast1DistMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                            Graph state variables                            %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.statevariables.parent = uimenu('Parent',controls.toolsmenu, ...
   'Label','&State Variables', ...
   'Tag','StateVariablesMenu');
%
controls.statevariables.initialvalues = uimenu('Parent',controls.statevariables.parent, ...
   'Label','&Initial Values...', ...
   'Callback','ToolsMenuFunctions StateVariablesInitialValues', ...
   'Enable','off', ...
   'Tag','StateVariablesInitialValuesMenu');
%
controls.statevariables.prior = uimenu('Parent',controls.statevariables.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','ToolsMenuFunctions StateVariablesPriorDist', ...
   'Enable','off', ...
   'Tag','StateVariablesPriorDistMenu');
%
controls.statevariables.postmode = uimenu('Parent',controls.statevariables.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','ToolsMenuFunctions StateVariablesPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','StateVariablesPosteriorModeMenu');
%
controls.statevariables.posterior = uimenu('Parent',controls.statevariables.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ToolsMenuFunctions StateVariablesPosteriorDist', ...
   'Enable','off', ...
   'Tag','StateVariablesDistMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                             Graph state shocks                              %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.stateshocks.parent = uimenu('Parent',controls.toolsmenu, ...
   'Label','State Shoc&ks', ...
   'Tag','StateShocksParentMenu');
%
controls.stateshocks.initialvalues = uimenu('Parent',controls.stateshocks.parent, ...
   'Label','&Initial Values...', ...
   'Callback','ToolsMenuFunctions ShocksInitialValues', ...
   'Enable','off', ...
   'Tag','StateShocksInitialValuesMenu');
%
controls.stateshocks.prior = uimenu('Parent',controls.stateshocks.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','ToolsMenuFunctions ShocksPriorDist', ...
   'Enable','off', ...
   'Tag','StateShocksPriorDistMenu');
%
controls.stateshocks.postmode = uimenu('Parent',controls.stateshocks.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','ToolsMenuFunctions ShocksPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','StateShocksPosteriorModeMenu');
%
controls.stateshocks.posterior = uimenu('Parent',controls.stateshocks.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ToolsMenuFunctions ShocksPosteriorDist', ...
   'Enable','off', ...
   'Tag','StateShocksDistMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                          Graph measurement errors                           %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.measurementerror.parent = uimenu('Parent',controls.toolsmenu, ...
   'Label','&Measurement Errors', ...
   'Tag','MeasurementErrorParentMenu');
%
controls.measurementerror.initialvalues = uimenu('Parent',controls.measurementerror.parent, ...
   'Label','&Initial Values...', ...
   'Callback','ToolsMenuFunctions MEInitialValues', ...
   'Enable','off', ...
   'Tag','MeasurementErrorInitialValuesMenu');
%
controls.measurementerror.prior = uimenu('Parent',controls.measurementerror.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','ToolsMenuFunctions MEPriorDist', ...
   'Enable','off', ...
   'Tag','MeasurementErrorPriorDistMenu');
%
controls.measurementerror.postmode = uimenu('Parent',controls.measurementerror.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','ToolsMenuFunctions MEPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','MeasurementErrorPosteriorModeMenu');
%
controls.measurementerror.posterior = uimenu('Parent',controls.measurementerror.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ToolsMenuFunctions MEPosteriorDist', ...
   'Enable','off', ...
   'Tag','MeasurementErrorDistMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                      Graph the log-likelihood function                      %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.loglikelihood.parent = uimenu('Parent',controls.toolsmenu, ...
   'Separator','on', ...
   'Label','&Log-likelihood Function', ...
   'Tag','LogLikelihoodMenu');
%
controls.loglikelihood.initialvalues = uimenu('Parent',controls.loglikelihood.parent, ...
   'Label','&Initial Values...', ...
   'Callback','ToolsMenuFunctions LogLikelihoodInitialValues', ...
   'Enable','off', ...
   'Tag','LogLikelihoodInitialValuesMenu');
%
controls.loglikelihood.postmode = uimenu('Parent',controls.loglikelihood.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','ToolsMenuFunctions LogLikelihoodPostMode', ...
   'Enable','off', ...
   'Tag','LogLikelihoodPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                               Shock scenarios                               %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
if FileExist(FixFilePath([pwd '\addons\sss\ShockScenarioControls.m']))==1;
   controls = ShockScenarioControls(controls);
   SepStr = 'off';
else;
   SepStr = 'on';
end;
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                         Observed variable scenarios                         %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
if FileExist(FixFilePath([pwd '\addons\ovs\OVSControls.m']))==1;
   controls = OVSControls(controls,'toolsmenu');
end;
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                             Parameter scenarios                             %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.ps.parent = uimenu('Parent',controls.toolsmenu, ...
   'Separator',SepStr, ...
   'Label','Parameter Sce&narios', ...
   'Tag','ParameterScenariosParentMenu');
%
% original data
%
controls.ps.original = uimenu('Parent',controls.ps.parent, ...
   'Label','&Original Data', ...
   'Tag','ParameterScenariosOriginalMenu');
%
% Initial values 
%
controls.ps.initialvalues = uimenu('Parent',controls.ps.original, ...
   'Label','&Initial Values...', ...
   'Callback','ToolsMenuFunctions ParameterScenariosInitialValues', ...
   'Enable','off', ...
   'Tag','ParameterScenarioInitialValuesMenu');
%
% posterior mode estimates
%
controls.ps.postmode = uimenu('Parent',controls.ps.original, ...
   'Label','&Posterior Mode...', ...
   'Callback','ToolsMenuFunctions ParameterScenariosPostMode', ...
   'Enable','off', ...
   'Tag','ParameterScenarioPosteriorModeMenu');
%
% annualized data
%
controls.ps.annual = uimenu('Parent',controls.ps.parent, ...
   'Label','&Annualized Data', ...
   'Tag','ParameterScenariosAnnualMenu');
%
% initial values
%
controls.ps.anninitialvalues = uimenu('Parent',controls.ps.annual, ...
   'Label','&Initial Values...', ...
   'Callback','ToolsMenuFunctions ParameterScenariosInitialValues', ...
   'Enable','off', ...
   'Tag','AnnualParameterScenarioPosteriorModeMenu');
%
% posterior mode estimates
%
controls.ps.annpostmode = uimenu('Parent',controls.ps.annual, ...
   'Label','&Posterior Mode...', ...
   'Callback','ToolsMenuFunctions ParameterScenariosPostMode', ...
   'Enable','off', ...
   'Tag','AnnualParameterScenarioPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                          Predictive distributions                           %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.predict.parent = uimenu('Parent',controls.toolsmenu, ...
   'Label','&Predictive Distributions', ...
   'Tag','PredictiveDistParentMenu');
%
% unconditional
%
controls.predict.unconditional = uimenu('Parent',controls.predict.parent, ...
   'Label','&Unconditional', ...
   'Tag','UnconditionalPredictiveDistMenu');
%
% conditional
%
controls.predict.conditional = uimenu('Parent',controls.predict.parent, ...
   'Label','&Conditional', ...
   'Tag','ConditionalPredictiveDistMenu');
%
% original data
%
controls.predict.unconditional_original = uimenu('Parent',controls.predict.unconditional, ...
   'Label','&Original Data', ...
   'Tag','UnconditionalOriginalPredictiveDistMenu');
%
controls.predict.conditional_original = uimenu('Parent',controls.predict.conditional, ...
   'Label','&Original Data', ...
   'Tag','ConditionalOriginalPredictiveDistMenu');
%
% annualized data
%
controls.predict.unconditional_annual = uimenu('Parent',controls.predict.unconditional, ...
   'Label','&Annualized Data', ...
   'Tag','UnconditionalAnnualizedPredictiveDistMenu');
%
controls.predict.conditional_annual = uimenu('Parent',controls.predict.conditional, ...
   'Label','&Annualized Data', ...
   'Tag','ConditionalAnnualizedPredictiveDistMenu');
%
% transformed data
%
controls.predict.unconditional_transformed = uimenu('Parent',controls.predict.unconditional, ...
   'Label','&Transformed Data', ...
   'Tag','UnConditionalTransformedPredictiveDistMenu');
%
controls.predict.conditional_transformed = uimenu('Parent',controls.predict.conditional, ...
   'Label','&Transformed Data', ...
   'Tag','ConditionalTransformedPredictiveDistMenu');
%
% predictive density height
%
controls.predict.unconditional = [];
controls.predict.unconditional.original = [];
controls.predict.unconditional.annual = [];
%
controls.predict.unconditional.original.heightparent = uimenu('Parent',controls.predict.unconditional_original, ...
   'Label','Predictive &Likelihood', ...
   'Enable','on', ...
   'Tag','UnconditionalPredictiveDensityHeightOriginalMenu');
%
controls.predict.unconditional.annual.heightparent = uimenu('Parent',controls.predict.unconditional_annual, ...
   'Label','Predictive &Likelihood', ...
   'Enable','on', ...
   'Tag','UnconditionalPredictiveDensityHeightAnnualizedMenu');
%
% continuous ranked probability score
%
controls.predict.unconditional.original.crpsparent = uimenu('Parent',controls.predict.unconditional_original, ...
   'Label','&CRPS', ...
   'Enable','on', ...
   'Tag','UnconditionalCRPSOriginalMenu');
%
controls.predict.unconditional.annual.crpsparent = uimenu('Parent',controls.predict.unconditional_annual, ...
   'Label','&CRPS', ...
   'Enable','on', ...
   'Tag','UnconditionalCRPSAnnualizedMenu');
%
% marginal predictive moments
%
controls.predict.unconditional.original.momentsparent = uimenu('Parent',controls.predict.unconditional_original, ...
   'Label','&Marginal Predictive Moments', ...
   'Enable','on', ...
   'Tag','UnconditionalPredictiveDensityMomentsOriginalMenu');
%
% probability integral transform
%
controls.predict.unconditional.original.pitparent = uimenu('Parent',controls.predict.unconditional_original, ...
   'Label','Pro&bability Integral Transform', ...
   'Enable','on', ...
   'Tag','UnconditionalPITOriginalMenu');
%
% stationary forecast error variance decomposition into state, shock, measurement error and parameter uncertainty.
%
controls.predict.unconditional.original.variancedecompparent = uimenu('Parent',controls.predict.unconditional_original, ...
   'Label','&Stationary Predictive Variance', ...
   'Enable','on', ...
   'Tag','UnconditionalVarianceDecompOriginalMenu');
%
% Zero lower bound menu controls
%
controls.predict.unconditional.original.zlbmenu = uimenu('Parent',controls.predict.unconditional_original, ...
   'Label','&Zero Lower Bound', ...
   'Enable','off', ...
   'Tag','UnconditionalOriginalZLBPredictiveDistMenu');
%
controls.predict.unconditional.annual.zlbmenu = uimenu('Parent',controls.predict.unconditional_annual, ...
   'Label','&Zero Lower Bound', ...
   'Enable','off', ...
   'Tag','UnconditionalAnnualZLBPredictiveDistMenu');
%
controls.predict.unconditional.transformed.zlbmenu = uimenu('Parent',controls.predict.unconditional_transformed, ...
   'Label','&Zero Lower Bound', ...
   'Enable','off', ...
   'Tag','UnconditionalTransformedZLBPredictiveDistMenu');
%
% observation weight decompositions of point forecasts
%
controls.predict.unconditional.original.obsweightdecompmenu = uimenu('Parent',controls.predict.unconditional_original, ...
   'Label','&Observation Weight Decomposition', ...
   'Enable','on', ...
   'Tag','UnconditionalOriginalObsWeightDecompMenu');
%
controls.predict.unconditional.annual.obsweightdecompmenu = uimenu('Parent',controls.predict.unconditional_annual, ...
   'Label','&Observation Weight Decomposition', ...
   'Enable','on', ...
   'Tag','UnconditionalAnnualObsWeightDecompMenu');
%
% conditional forecasts
%
controls.predict.conditional = [];
controls.predict.conditional.original = [];
controls.predict.conditional.annual = [];
controls.predict.conditional.transformed = [];
%
% predictive likelihood
%
controls.predict.conditional.original.heightparent = uimenu('Parent',controls.predict.conditional_original, ...
   'Label','Predictive &Likelihood', ...
   'Enable','on', ...
   'Tag','ConditionalPredHeightOriginalMenu');
%
controls.predict.conditional.annual.heightparent = uimenu('Parent',controls.predict.conditional_annual, ...
   'Label','Predictive &Likelihood', ...
   'Enable','on', ...
   'Tag','ConditionalPredHeightAnnualizedMenu');
%
% continuous ranked probability score
%
controls.predict.conditional.original.crpsparent = uimenu('Parent',controls.predict.conditional_original, ...
   'Label','&CRPS', ...
   'Enable','on', ...
   'Tag','ConditionalCRPSOriginalMenu');
%
controls.predict.conditional.annual.crpsparent = uimenu('Parent',controls.predict.conditional_annual, ...
   'Label','&CRPS', ...
   'Enable','on', ...
   'Tag','ConditionalCRPSAnnualizedMenu');
%
% marginal predictive moments
%
controls.predict.conditional.original.momentsparent = uimenu('Parent',controls.predict.conditional_original, ...
   'Label','&Marginal Predictive Moments', ...
   'Enable','on', ...
   'Tag','ConditionalPredictiveDensityMomentsOriginalMenu');
%
% probability integral transform
%
controls.predict.conditional.original.pitparent = uimenu('Parent',controls.predict.conditional_original, ...
   'Label','Pro&bability Integral Transform', ...
   'Enable','on', ...
   'Tag','ConditionalPITOriginalMenu');
%
% prior distribution
%
controls.predict.conditional.original.height.prior = uimenu('Parent',controls.predict.conditional.original.heightparent, ...
   'Label','P&rior Distribution...', ...
   'Callback','ForecastToolsMenuFunctions ConPredHeightPriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalPredHeightOriginalPriorDistMenu');
%
controls.predict.conditional.annual.height.prior = uimenu('Parent',controls.predict.conditional.annual.heightparent, ...
   'Label','P&rior Distribution...', ...
   'Callback','ForecastToolsMenuFunctions ConPredHeightPriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalPredHeightAnnualizedPriorDistMenu');
%
controls.predict.conditional.original.crps.prior = uimenu('Parent',controls.predict.conditional.original.crpsparent, ...
   'Label','P&rior Distribution...', ...
   'Callback','ForecastToolsMenuFunctions ConCRPSPriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalCRPSOriginalPriorDistMenu');
%
controls.predict.conditional.annual.crps.prior = uimenu('Parent',controls.predict.conditional.annual.crpsparent, ...
   'Label','P&rior Distribution...', ...
   'Callback','ForecastToolsMenuFunctions ConCRPSPriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalCRPSAnnualizedPriorDistMenu');
%
controls.predict.conditional.original.moments.prior = uimenu('Parent',controls.predict.conditional.original.momentsparent, ...
   'Label','P&rior Distribution...', ...
   'Callback','ForecastToolsMenuFunctions ConMargPredMomentsPriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalPredictiveDensityMomentsOriginalPriorDistMenu');
%
controls.predict.conditional.original.pit.prior = uimenu('Parent',controls.predict.conditional.original.pitparent, ...
   'Label','P&rior Distribution...', ...
   'Callback','ForecastToolsMenuFunctions ConPITPriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalPITOriginalPriorDistMenu');
%
% posterior distribution
%
controls.predict.conditional.original.height.posterior = uimenu('Parent',controls.predict.conditional.original.heightparent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ForecastToolsMenuFunctions ConPredHeightPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalPredHeightOriginalPosteriorDistMenu');
%
controls.predict.conditional.annual.height.posterior = uimenu('Parent',controls.predict.conditional.annual.heightparent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ForecastToolsMenuFunctions ConPredHeightPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalPredHeightAnnualizedPosteriorDistMenu');
%
controls.predict.conditional.original.crps.posterior = uimenu('Parent',controls.predict.conditional.original.crpsparent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ForecastToolsMenuFunctions ConCRPSPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalCRPSOriginalPosteriorDistMenu');
%
controls.predict.conditional.annual.crps.posterior = uimenu('Parent',controls.predict.conditional.annual.crpsparent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ForecastToolsMenuFunctions ConCRPSPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalCRPSAnnualizedPosteriorDistMenu');
%
controls.predict.conditional.original.moments.posterior = uimenu('Parent',controls.predict.conditional.original.momentsparent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ForecastToolsMenuFunctions ConMargPredMomentsPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalPredictiveDensityMomentsOriginalPosteriorDistMenu');
%
controls.predict.conditional.original.pit.posterior = uimenu('Parent',controls.predict.conditional.original.pitparent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ForecastToolsMenuFunctions ConPITPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalPITOriginalPosteriorDistMenu');
%
% zlb items
%
controls.predict.conditional.original.zlbmenu = uimenu('Parent',controls.predict.conditional_original, ...
   'Label','&Zero Lower Bound', ...
   'Enable','off', ...
   'Tag','ConditionalOriginalZLBPredictiveDistMenu');
%
controls.predict.conditional.annual.zlbmenu = uimenu('Parent',controls.predict.conditional_annual, ...
   'Label','&Zero Lower Bound', ...
   'Enable','off', ...
   'Tag','ConditionalAnnualZLBPredictiveDistMenu');
%
controls.predict.conditional.transformed.zlbmenu = uimenu('Parent',controls.predict.conditional_transformed, ...
   'Label','&Zero Lower Bound', ...
   'Enable','off', ...
   'Tag','ConditionalTransformedZLBPredictiveDistMenu');
%
% initial values
%
controls.predict.unconditional.original.height.initialvalues = uimenu('Parent',controls.predict.unconditional.original.heightparent, ...
   'Label','&Initial Values...', ...
   'Callback','ForecastToolsMenuFunctions UnconPredHeightInitialValues', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDensityHeightOriginalInitialValuesMenu');
%
controls.predict.unconditional.annual.height.initialvalues = uimenu('Parent',controls.predict.unconditional.annual.heightparent, ...
   'Label','&Initial Values...', ...
   'Callback','ForecastToolsMenuFunctions UnconPredHeightInitialValues', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDensityHeightAnnualizedInitialValuesMenu');
%
% prior distribution
%
controls.predict.unconditional.original.height.prior = uimenu('Parent',controls.predict.unconditional.original.heightparent, ...
   'Label','P&rior Distribution...', ...
   'Callback','ForecastToolsMenuFunctions UnconPredHeightPriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDensityHeightOriginalPriorDistMenu');
%
controls.predict.unconditional.annual.height.prior = uimenu('Parent',controls.predict.unconditional.annual.heightparent, ...
   'Label','P&rior Distribution...', ...
   'Callback','ForecastToolsMenuFunctions UnconPredHeightPriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDensityHeightAnnualizedPriorDistMenu');
%
controls.predict.unconditional.original.crps.prior = uimenu('Parent',controls.predict.unconditional.original.crpsparent, ...
   'Label','P&rior Distribution...', ...
   'Callback','ForecastToolsMenuFunctions UnconCRPSPriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalCRPSOriginalPriorDistMenu');
%
controls.predict.unconditional.annual.crps.prior = uimenu('Parent',controls.predict.unconditional.annual.crpsparent, ...
   'Label','P&rior Distribution...', ...
   'Callback','ForecastToolsMenuFunctions UnconCRPSPriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalCRPSAnnualizedPriorDistMenu');
%
controls.predict.unconditional.original.moments.prior = uimenu('Parent',controls.predict.unconditional.original.momentsparent, ...
   'Label','P&rior Distribution...', ...
   'Callback','ForecastToolsMenuFunctions UnconMargPredMomentsPriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDensityMomentsOriginalPriorDistMenu');
%
controls.predict.unconditional.original.pit.prior = uimenu('Parent',controls.predict.unconditional.original.pitparent, ...
   'Label','P&rior Distribution...', ...
   'Callback','ForecastToolsMenuFunctions UnconPITPriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalPITOriginalPriorDistMenu');
%
controls.predict.unconditional.original.variancedecomp.prior = uimenu('Parent',controls.predict.unconditional.original.variancedecompparent, ...
   'Label','P&rior Distribution...', ...
   'Callback','ForecastToolsMenuFunctions UnconStationaryPredVariancePriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveVarianceOriginalPriorDistMenu');
%
% posterior mode
%
controls.predict.unconditional.original.height.postmode = uimenu('Parent',controls.predict.unconditional.original.heightparent, ...
   'Label','&Posterior Mode...', ...
   'Callback','ForecastToolsMenuFunctions UnconPredHeightPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDensityHeightOriginalPosteriorModeMenu');
%
controls.predict.unconditional.annual.height.postmode = uimenu('Parent',controls.predict.unconditional.annual.heightparent, ...
   'Label','&Posterior Mode...', ...
   'Callback','ForecastToolsMenuFunctions UnconPredHeightPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDensityHeightAnnualizedPosteriorModeMenu');
%
% posterior distribution
%
controls.predict.unconditional.original.height.posterior = uimenu('Parent',controls.predict.unconditional.original.heightparent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ForecastToolsMenuFunctions UnconPredHeightPosteriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDensityHeightOriginalPosteriorDistMenu');
%
controls.predict.unconditional.annual.height.posterior = uimenu('Parent',controls.predict.unconditional.annual.heightparent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ForecastToolsMenuFunctions UnconPredHeightPosteriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDensityHeightAnnualizedPosteriorDistMenu');
%
controls.predict.unconditional.original.crps.posterior = uimenu('Parent',controls.predict.unconditional.original.crpsparent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ForecastToolsMenuFunctions UnconCRPSPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalCRPSOriginalPosteriorDistMenu');
%
controls.predict.unconditional.annual.crps.posterior = uimenu('Parent',controls.predict.unconditional.annual.crpsparent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ForecastToolsMenuFunctions UnconCRPSPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalCRPSAnnualizedPosteriorDistMenu');
%
controls.predict.unconditional.original.moments.posterior = uimenu('Parent',controls.predict.unconditional.original.momentsparent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ForecastToolsMenuFunctions UnconMargPredMomentsPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDensityMomentsOriginalPosteriorDistMenu');
%
controls.predict.unconditional.original.pit.posterior = uimenu('Parent',controls.predict.unconditional.original.pitparent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ForecastToolsMenuFunctions UnconPITPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalPITOriginalPosteriorDistMenu');
%
controls.predict.unconditional.original.variancedecomp.posterior = uimenu('Parent',controls.predict.unconditional.original.variancedecompparent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ForecastToolsMenuFunctions UnconStationaryPredVariancePosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDensityMomentsOriginalPosteriorDistMenu');
%
% initial values
%
controls.predict.unconditional_original_initialvalues = uimenu('Parent',controls.predict.unconditional_original, ...
   'Label','&Initial Values...', ...
   'Callback','ForecastToolsMenuFunctions UnconPredInitialValues', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDistOriginalInitialValuesMenu');
%
controls.predict.conditional_original_initialvalues = uimenu('Parent',controls.predict.conditional_original, ...
   'Label','&Initial Values...', ...
   'Callback','ForecastToolsMenuFunctions ConPredInitialValues', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalPredictiveDistOriginalInitialValuesMenu');
%
% prior distribution
%
controls.predict.unconditional_original_prior = uimenu('Parent',controls.predict.unconditional_original, ...
   'Label','P&rior Distribution...', ...
   'Callback','ForecastToolsMenuFunctions UnconPredPriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDistOriginalPriorMenu');
%
controls.predict.conditional_original_prior = uimenu('Parent',controls.predict.conditional_original, ...
   'Label','P&rior Distribution...', ...
   'Callback','ForecastToolsMenuFunctions ConPredPriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalPredictiveDistOriginalPriorMenu');
%
% posterior mode
%
controls.predict.unconditional_original_postmode = uimenu('Parent',controls.predict.unconditional_original, ...
   'Label','&Posterior Mode...', ...
   'Callback','ForecastToolsMenuFunctions UnconPredPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDistOriginalPostModeMenu');
%
controls.predict.conditional_original_postmode = uimenu('Parent',controls.predict.conditional_original, ...
   'Label','&Posterior Mode...', ...
   'Callback','ForecastToolsMenuFunctions ConPredPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalPredictiveDistOriginalPostModeMenu');
%
% posterior distribution
%
controls.predict.unconditional_original_posterior = uimenu('Parent',controls.predict.unconditional_original, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ForecastToolsMenuFunctions UnconPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDistOriginalPosteriorMenu');
%
controls.predict.conditional_original_posterior = uimenu('Parent',controls.predict.conditional_original, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ForecastToolsMenuFunctions ConPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalPredictiveDistOriginalPosteriorMenu');
%
% predictive events
%
controls.predict.unconditional_original_predevent = uimenu('Parent',controls.predict.unconditional_original, ...
   'Label','Prediction &Event...', ...
   'Callback','ForecastToolsMenuFunctions UnconPredictionEvent', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveEventOriginalPosteriorMenu');
%
controls.predict.conditional_original_predevent = uimenu('Parent',controls.predict.conditional_original, ...
   'Label','Prediction &Event...', ...
   'Callback','ForecastToolsMenuFunctions ConPredictionEvent', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalPredictiveEventOriginalPosteriorMenu');
%
% annualized data
%
controls.predict.unconditional_annual_initialvalues = uimenu('Parent',controls.predict.unconditional_annual, ...
   'Label','&Initial Values...', ...
   'Separator','on', ...
   'Callback','ForecastToolsMenuFunctions UnconPredInitialValues', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDistAnnualizedInitialValuesMenu');
%
controls.predict.conditional_annual_initialvalues = uimenu('Parent',controls.predict.conditional_annual, ...
   'Label','&Initial Values...', ...
   'Callback','ForecastToolsMenuFunctions ConPredInitialValues', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalPredictiveDistAnnualizedInitialValuesMenu');
%
controls.predict.unconditional_annual_prior = uimenu('Parent',controls.predict.unconditional_annual, ...
   'Label','P&rior Distribution...', ...
   'Callback','ForecastToolsMenuFunctions UnconPredPriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDistAnnualizedPriorMenu');
%
controls.predict.conditional_annual_prior = uimenu('Parent',controls.predict.conditional_annual, ...
   'Label','P&rior Distribution...', ...
   'Callback','ForecastToolsMenuFunctions ConPredPriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalPredictiveDistAnnualizedPriorMenu');
%
controls.predict.unconditional_annual_postmode = uimenu('Parent',controls.predict.unconditional_annual, ...
   'Label','&Posterior Mode...', ...
   'Callback','ForecastToolsMenuFunctions UnconPredPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDistAnnualizedPostModeMenu');
%
controls.predict.conditional_annual_postmode = uimenu('Parent',controls.predict.conditional_annual, ...
   'Label','&Posterior Mode...', ...
   'Callback','ForecastToolsMenuFunctions ConPredPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalPredictiveDistAnnualizedPostModeMenu');
%
controls.predict.unconditional_annual_posterior = uimenu('Parent',controls.predict.unconditional_annual, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ForecastToolsMenuFunctions UnconPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDistAnnualizedPosteriorMenu');
%
controls.predict.conditional_annual_posterior = uimenu('Parent',controls.predict.conditional_annual, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ForecastToolsMenuFunctions ConPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalPredictiveDistAnnualizedPosteriorMenu');
%
controls.predict.unconditional_annual_predevent = uimenu('Parent',controls.predict.unconditional_annual, ...
   'Label','Prediction &Event...', ...
   'Callback','ForecastToolsMenuFunctions UnconPredictionEvent', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveEventAnnualizedPosteriorMenu');
%
controls.predict.conditional_annual_predevent = uimenu('Parent',controls.predict.conditional_annual, ...
   'Label','Prediction &Event...', ...
   'Callback','ForecastToolsMenuFunctions ConPredictionEvent', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalPredictiveEventAnnualizedPosteriorMenu');
%
% transformed data
%
% initial values
%
controls.predict.unconditional_transformed_initialvalues = uimenu('Parent',controls.predict.unconditional_transformed, ...
   'Label','&Initial Values...', ...
   'Callback','ForecastToolsMenuFunctions UnconPredInitialValues', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDistTransformedInitialValuesMenu');
%
controls.predict.conditional_transformed_initialvalues = uimenu('Parent',controls.predict.conditional_transformed, ...
   'Label','&Initial Values...', ...
   'Callback','ForecastToolsMenuFunctions ConPredInitialValues', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalPredictiveDistTransformedInitialValuesMenu');
%
% prior distribution
%
controls.predict.unconditional_transformed_prior = uimenu('Parent',controls.predict.unconditional_transformed, ...
   'Label','P&rior Distribution...', ...
   'Callback','ForecastToolsMenuFunctions UnconPredPriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDistTransformedPriorMenu');
%
controls.predict.conditional_transformed_prior = uimenu('Parent',controls.predict.conditional_transformed, ...
   'Label','P&rior Distribution...', ...
   'Callback','ForecastToolsMenuFunctions ConPredPriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalPredictiveDistTransformedPriorMenu');
%
% posterior mode values
%
controls.predict.unconditional_transformed_postmode = uimenu('Parent',controls.predict.unconditional_transformed, ...
   'Label','&Posterior Mode...', ...
   'Callback','ForecastToolsMenuFunctions UnconPredPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDistTransformedPostModeMenu');
%
controls.predict.conditional_transformed_postmode = uimenu('Parent',controls.predict.conditional_transformed, ...
   'Label','&Posterior Mode...', ...
   'Callback','ForecastToolsMenuFunctions ConPredPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalPredictiveDistTransformedPostModeMenu');
%
% posterior distribution
%
controls.predict.unconditional_transformed_posterior = uimenu('Parent',controls.predict.unconditional_transformed, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ForecastToolsMenuFunctions UnconPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveDistTransformedPosteriorMenu');
%
controls.predict.conditional_transformed_posterior = uimenu('Parent',controls.predict.conditional_transformed, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ForecastToolsMenuFunctions ConPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalPredictiveDistTransformedPosteriorMenu');
%
% predictive events
%
controls.predict.unconditional_transformed_predevent = uimenu('Parent',controls.predict.unconditional_transformed, ...
   'Label','Prediction &Event...', ...
   'Callback','ForecastToolsMenuFunctions UnconPredictionEvent', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalPredictiveEventTransformedPosteriorMenu');
%
controls.predict.conditional_transformed_predevent = uimenu('Parent',controls.predict.conditional_transformed, ...
   'Label','Prediction &Event...', ...
   'Callback','ForecastToolsMenuFunctions ConPredictionEvent', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalPredictiveEventTransformedPosteriorMenu');
%
% conditional predictions controls for the state variables
%
controls.predict.stateconditional = uimenu('Parent',controls.predict.parent, ...
      'Label','&State Conditional', ...
      'Tag','StateConditionalPredictiveDistMenu');
%
% original data
%
controls.predict.stateconditional_original = uimenu('Parent',controls.predict.stateconditional, ...
   'Label','&Original Data', ...
   'Tag','StateConditionalOriginalPredictiveDistMenu');
%
% annualized data
%
controls.predict.stateconditional_annual = uimenu('Parent',controls.predict.stateconditional, ...
   'Label','&Annualized Data', ...
   'Tag','StateConditionalAnnualizedPredictiveDistMenu');
%
% transformed data
%
controls.predict.stateconditional_transformed = uimenu('Parent',controls.predict.stateconditional, ...
   'Label','&Transformed Data', ...
   'Tag','StateConditionalTransformedPredictiveDistMenu');
%
% initial values
%
controls.predict.stateconditional_original_initialvalues = uimenu('Parent',controls.predict.stateconditional_original, ...
   'Label','&Initial Values...', ...
   'Callback','CondStateFunction InitialValues', ...
   'Enable','off', ...
   'Tag','StateConditionalPredictiveDistOriginalInitialValuesMenu');
%
controls.predict.stateconditional_annual_initialvalues = uimenu('Parent',controls.predict.stateconditional_annual, ...
   'Label','&Initial Values...', ...
   'Callback','CondStateFunction InitialValues', ...
   'Enable','off', ...
   'Tag','StateConditionalPredictiveDistAnnualizedInitialValuesMenu');
%
controls.predict.stateconditional_transformed_initialvalues = uimenu('Parent',controls.predict.stateconditional_transformed, ...
   'Label','&Initial Values...', ...
   'Callback','CondStateFunction InitialValues', ...
   'Enable','off', ...
   'Tag','StateConditionalPredictiveDistTransformedInitialValuesMenu');
%
% prior distribution
%
controls.predict.stateconditional_original_prior = uimenu('Parent',controls.predict.stateconditional_original, ...
   'Label','P&rior Distribution...', ...
   'Callback','CondStateFunction PriorDistribution', ...
   'Enable','off', ...
   'Tag','StateConditionalPredictiveDistOriginalPriorMenu');
%
controls.predict.stateconditional_annual_prior = uimenu('Parent',controls.predict.stateconditional_annual, ...
   'Label','P&rior Distribution...', ...
   'Callback','CondStateFunction PriorDistribution', ...
   'Enable','off', ...
   'Tag','StateConditionalPredictiveDistAnnualizedPriorMenu');
%
controls.predict.stateconditional_transformed_prior = uimenu('Parent',controls.predict.stateconditional_transformed, ...
   'Label','P&rior Distribution...', ...
   'Callback','CondStateFunction PriorDistribution', ...
   'Enable','off', ...
   'Tag','StateConditionalPredictiveDistTransformedPriorMenu');
%
% posterior mode
%
controls.predict.stateconditional_original_postmode = uimenu('Parent',controls.predict.stateconditional_original, ...
   'Label','&Posterior Mode...', ...
   'Callback','CondStateFunction PosteriorMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','StateConditionalPredictiveDistOriginalPostModeMenu');
%
controls.predict.stateconditional_annual_postmode = uimenu('Parent',controls.predict.stateconditional_annual, ...
   'Label','&Posterior Mode...', ...
   'Callback','CondStateFunction PosteriorMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','StateConditionalPredictiveDistAnnualizedPostModeMenu');
%
controls.predict.stateconditional_transformed_postmode = uimenu('Parent',controls.predict.stateconditional_transformed, ...
   'Label','&Posterior Mode...', ...
   'Callback','CondStateFunction PosteriorMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','StateConditionalPredictiveDistTransformedPostModeMenu');
%
% posterior distribution
%
controls.predict.stateconditional_original_posterior = uimenu('Parent',controls.predict.stateconditional_original, ...
   'Label','Posterior &Distribution...', ...
   'Callback','CondStateFunction PosteriorDistribution', ...
   'Enable','off', ...
   'Tag','StateConditionalPredictiveDistOriginalPosteriorMenu');
%
controls.predict.stateconditional_annual_posterior = uimenu('Parent',controls.predict.stateconditional_annual, ...
   'Label','Posterior &Distribution...', ...
   'Callback','CondStateFunction PosteriorDistribution', ...
   'Enable','off', ...
   'Tag','StateConditionalPredictiveDistAnnualizedPosteriorMenu');
%
controls.predict.stateconditional_transformed_posterior = uimenu('Parent',controls.predict.stateconditional_transformed, ...
   'Label','Posterior &Distribution...', ...
   'Callback','CondStateFunction PosteriorDistribution', ...
   'Enable','off', ...
   'Tag','StateConditionalPredictiveDistTransformedPosteriorMenu');
%
% prediction event
%
controls.predict.stateconditional_original_predevent = uimenu('Parent',controls.predict.stateconditional_original, ...
   'Label','Prediction &Event...', ...
   'Callback','CondStateFunction PredictionEvent', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','StateConditionalPredictiveEventOriginalPosteriorMenu');
%
controls.predict.stateconditional_annual_predevent = uimenu('Parent',controls.predict.stateconditional_annual, ...
   'Label','Prediction &Event...', ...
   'Callback','CondStateFunction PredictionEvent', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','StateConditionalPredictiveEventAnnualizedPosteriorMenu');
%
controls.predict.stateconditional_transformed_predevent = uimenu('Parent',controls.predict.stateconditional_transformed, ...
   'Label','Prediction &Event...', ...
   'Callback','CondStateFunction PredictionEvent', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','StateConditionalPredictiveEventTransformedPosteriorMenu');
%
% view actuals over the prediction horizon
%
controls.predict.actuals = uimenu('Parent',controls.predict.parent, ...
      'Label','&View Actuals...', ...
      'Separator','on', ...
      'Callback','ForecastToolsMenuFunctions ViewActuals', ...
      'Enable','off', ...
      'Tag','ViewActualsDataMenu');
%
% zlb menu controls
%
% predictive likelihood controls
%
controls.predict.unconditional.original.zlb.heightmenu = uimenu('Parent',controls.predict.unconditional.original.zlbmenu, ...
   'Label','Predictive &Likelihood', ...
   'Enable','on', ...
   'Tag','UnconditionalPredictiveDensityHeightOriginalZLBMenu');
%
controls.predict.unconditional.annual.zlb.heightmenu = uimenu('Parent',controls.predict.unconditional.annual.zlbmenu, ...
   'Label','Predictive &Likelihood', ...
   'Enable','on', ...
   'Tag','UnconditionalPredictiveDensityHeightAnnualizedZLBMenu');
%
% crps controls for unconditional predictions subject to ZLB
%
controls.predict.unconditional.original.zlb.crpsmenu = uimenu('Parent',controls.predict.unconditional.original.zlbmenu, ...
   'Label','&CRPS', ...
   'Enable','on', ...
   'Tag','UnconditionalCRPSOriginalZLBMenu');
%
controls.predict.unconditional.annual.zlb.crpsmenu = uimenu('Parent',controls.predict.unconditional.annual.zlbmenu, ...
   'Label','&CRPS', ...
   'Enable','on', ...
   'Tag','UnconditionalCRPSAnnualZLBMenu');
%
% prior distribution
%
controls.predict.unconditional.original.zlb.height.prior = uimenu('Parent',controls.predict.unconditional.original.zlb.heightmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions UnconPredHeightPriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalZLBOriginalPredHeightPriorMenu');
%
controls.predict.unconditional.annual.zlb.height.prior = uimenu('Parent',controls.predict.unconditional.annual.zlb.heightmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions UnconPredHeightPriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalZLBAnnualPredHeightPriorMenu');
%
controls.predict.unconditional.original.zlb.crps.prior = uimenu('Parent',controls.predict.unconditional.original.zlb.crpsmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions UnconCRPSPriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalZLBOriginalCRPSPriorMenu');
%
controls.predict.unconditional.annual.zlb.crps.prior = uimenu('Parent',controls.predict.unconditional.annual.zlb.crpsmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions UnconCRPSPriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalZLBAnnualCRPSPriorMenu');
%
% posterior distribution
%
controls.predict.unconditional.original.zlb.height.posterior = uimenu('Parent',controls.predict.unconditional.original.zlb.heightmenu, ...
   'Label','&Posterior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions UnconPredHeightPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalZLBOriginalPredHeightPosteriorMenu');
%
controls.predict.unconditional.annual.zlb.height.posterior = uimenu('Parent',controls.predict.unconditional.annual.zlb.heightmenu, ...
   'Label','&Posterior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions UnconPredHeightPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalZLBAnnualPredHeightPosteriorMenu');
%
controls.predict.unconditional.original.zlb.crps.posterior = uimenu('Parent',controls.predict.unconditional.original.zlb.crpsmenu, ...
   'Label','&Posterior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions UnconCRPSPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalZLBOriginalCRPSPosteriorMenu');
%
controls.predict.unconditional.annual.zlb.crps.posterior = uimenu('Parent',controls.predict.unconditional.annual.zlb.crpsmenu, ...
   'Label','&Posterior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions UnconCRPSPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalZLBAnnualCRPSPosteriorMenu');
%
% unconditional
%
controls.predict.unconditional.original.zlb.initialvalues = uimenu('Parent',controls.predict.unconditional.original.zlbmenu, ...
   'Label','&Initial Values...', ...
   'Callback','ZLBForecastToolsMenuFunctions UnconPredInitialValues', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalZLBPredictiveDistOriginalInitialValuesMenu');
%
controls.predict.unconditional.annual.zlb.initialvalues = uimenu('Parent',controls.predict.unconditional.annual.zlbmenu, ...
   'Label','&Initial Value...', ...
   'Callback','ZLBForecastToolsMenuFunctions UnconPredInitialValues', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalZLBPredictiveDistAnnualInitialValuesMenu');
%
controls.predict.unconditional.transformed.zlb.initialvalues = uimenu('Parent',controls.predict.unconditional.transformed.zlbmenu, ...
   'Label','&Initial Values...', ...
   'Callback','ZLBForecastToolsMenuFunctions UnconPredInitialValues', ...
   'Enable','off', ...
   'Tag','UnconditionalZLBPredictiveDistTransformedInitialValuesMenu');
%
% prior distribution
%
controls.predict.unconditional.original.zlb.prior = uimenu('Parent',controls.predict.unconditional.original.zlbmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions UnconPredPriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalZLBPredictiveDistOriginalPriorMenu');
%
controls.predict.unconditional.annual.zlb.prior = uimenu('Parent',controls.predict.unconditional.annual.zlbmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions UnconPredPriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalZLBPredictiveDistAnnualPriorMenu');
%
controls.predict.unconditional.transformed.zlb.prior = uimenu('Parent',controls.predict.unconditional.transformed.zlbmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions UnconPredPriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalZLBPredictiveDistTransformedPriorMenu');
%
% Posterior mode
%
controls.predict.unconditional.original.zlb.postmode = uimenu('Parent',controls.predict.unconditional.original.zlbmenu, ...
   'Label','&Posterior Mode...', ...
   'Callback','ZLBForecastToolsMenuFunctions UnconPredPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalZLBPredictiveDistOriginalPostModeMenu');
%
controls.predict.unconditional.annual.zlb.postmode = uimenu('Parent',controls.predict.unconditional.annual.zlbmenu, ...
   'Label','&Posterior Mode...', ...
   'Callback','ZLBForecastToolsMenuFunctions UnconPredPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalZLBPredictiveDistAnnualPostModeMenu');
%
controls.predict.unconditional.transformed.zlb.postmode = uimenu('Parent',controls.predict.unconditional.transformed.zlbmenu, ...
   'Label','&Posterior Mode...', ...
   'Callback','ZLBForecastToolsMenuFunctions UnconPredPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','UnconditionalZLBPredictiveDistTransformedPostModeMenu');
%
% posterior distribution
%
controls.predict.unconditional.original.zlb.posterior = uimenu('Parent',controls.predict.unconditional.original.zlbmenu, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions UnconPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalZLBPredictiveDistOriginalPosteriorMenu');
%
controls.predict.unconditional.annual.zlb.posterior = uimenu('Parent',controls.predict.unconditional.annual.zlbmenu, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions UnconPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalZLBPredictiveDistAnnualPosteriorMenu');
%
controls.predict.unconditional.transformed.zlb.posterior = uimenu('Parent',controls.predict.unconditional.transformed.zlbmenu, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions UnconPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','UnconditionalZLBPredictiveDistTransformedPosteriorMenu');
%
% Observation weight controls
%
% initial values
%
controls.predict.unconditional.original.obsweightdecomp.initialvalues = uimenu('Parent',controls.predict.unconditional.original.obsweightdecompmenu, ...
   'Label','&Initial Values...', ...
   'Callback','ForecastToolsMenuFunctions UncondObsWeightDecompInitialValues', ...
   'Enable','off', ...
   'Tag','UnconditionalObsWeightDecompOriginalInitialValuesMenu');
%
controls.predict.unconditional.annual.obsweightdecomp.initialvalues = uimenu('Parent',controls.predict.unconditional.annual.obsweightdecompmenu, ...
   'Label','&Initial Value...', ...
   'Callback','ForecastToolsMenuFunctions UncondObsWeightDecompInitialValues', ...
   'Enable','off', ...
   'Tag','UnconditionalObsWeightDecompAnnualInitialValuesMenu');
%
% posterior mode values
%
controls.predict.unconditional.original.obsweightdecomp.postmode = uimenu('Parent',controls.predict.unconditional.original.obsweightdecompmenu, ...
   'Label','&Posterior Mode...', ...
   'Callback','ForecastToolsMenuFunctions UncondObsWeightDecompPostMode', ...
   'Enable','off', ...
   'Tag','UnconditionalObsWeightDecompOriginalPostModeMenu');
%
controls.predict.unconditional.annual.obsweightdecomp.postmode = uimenu('Parent',controls.predict.unconditional.annual.obsweightdecompmenu, ...
   'Label','&Posterior Mode...', ...
   'Callback','ForecastToolsMenuFunctions UncondObsWeightDecompPostMode', ...
   'Enable','off', ...
   'Tag','UnconditionalObsWeightDecompAnnualPostModeMenu');
%
% conditional
%
% predictive likelihood controls
%
controls.predict.conditional.original.zlb.heightmenu = uimenu('Parent',controls.predict.conditional.original.zlbmenu, ...
   'Label','Predictive &Likelihood', ...
   'Enable','on', ...
   'Tag','ConditionalPredictiveDensityHeightOriginalZLBMenu');
%
controls.predict.conditional.annual.zlb.heightmenu = uimenu('Parent',controls.predict.conditional.annual.zlbmenu, ...
   'Label','Predictive &Likelihood', ...
   'Enable','on', ...
   'Tag','ConditionalPredictiveDensityHeightAnnualizedZLBMenu');
%
% CRPS controls
%
controls.predict.conditional.original.zlb.crpsmenu = uimenu('Parent',controls.predict.conditional.original.zlbmenu, ...
   'Label','&CRPS', ...
   'Enable','on', ...
   'Tag','ConditionalCRPSOriginalZLBMenu');
%
controls.predict.conditional.annual.zlb.crpsmenu = uimenu('Parent',controls.predict.conditional.annual.zlbmenu, ...
   'Label','&CRPS', ...
   'Enable','on', ...
   'Tag','ConditionalCRPSAnnualZLBMenu');
%
% prior distribution
%
controls.predict.conditional.original.zlb.height.prior = uimenu('Parent',controls.predict.conditional.original.zlb.heightmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ConPredHeightPriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalZLBOriginalPredHeightPriorMenu');
%
controls.predict.conditional.annual.zlb.height.prior = uimenu('Parent',controls.predict.conditional.annual.zlb.heightmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ConPredHeightPriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalZLBAnnualPredHeightPriorMenu');
%
controls.predict.conditional.original.zlb.crps.prior = uimenu('Parent',controls.predict.conditional.original.zlb.crpsmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ConCRPSPriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalZLBOriginalCRPSPriorMenu');
%
controls.predict.conditional.annual.zlb.crps.prior = uimenu('Parent',controls.predict.conditional.annual.zlb.crpsmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ConCRPSPriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalZLBAnnualCRPSPriorMenu');
%
% posterior distribution
%
controls.predict.conditional.original.zlb.height.posterior = uimenu('Parent',controls.predict.conditional.original.zlb.heightmenu, ...
   'Label','&Posterior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ConPredHeightPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalZLBOriginalPredHeightPosteriorMenu');
%
controls.predict.conditional.annual.zlb.height.posterior = uimenu('Parent',controls.predict.conditional.annual.zlb.heightmenu, ...
   'Label','&Posterior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ConPredHeightPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalZLBAnnualPredHeightPosteriorMenu');
%
controls.predict.conditional.original.zlb.crps.posterior = uimenu('Parent',controls.predict.conditional.original.zlb.crpsmenu, ...
   'Label','&Posterior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ConCRPSPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalZLBOriginalCRPSPosteriorMenu');
%
controls.predict.conditional.annual.zlb.crps.posterior = uimenu('Parent',controls.predict.conditional.annual.zlb.crpsmenu, ...
   'Label','&Posterior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ConCRPSPosteriorDist', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalZLBAnnualCRPSPosteriorMenu');
%
% Initial values
%
controls.predict.conditional.original.zlb.initialvalues = uimenu('Parent',controls.predict.conditional.original.zlbmenu, ...
   'Label','&Initial Values...', ...
   'Callback','ZLBForecastToolsMenuFunctions ConPredInitialValues', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalZLBPredictiveDistOriginalInitialValuesMenu');
%
controls.predict.conditional.annual.zlb.initialvalues = uimenu('Parent',controls.predict.conditional.annual.zlbmenu, ...
   'Label','&Initial Value...', ...
   'Callback','ZLBForecastToolsMenuFunctions ConPredInitialValues', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalZLBPredictiveDistAnnualInitialValuesMenu');
%
controls.predict.conditional.transformed.zlb.initialvalues = uimenu('Parent',controls.predict.conditional.transformed.zlbmenu, ...
   'Label','&Initial Values...', ...
   'Callback','ZLBForecastToolsMenuFunctions ConPredInitialValues', ...
   'Enable','off', ...
   'Tag','ConditionalZLBPredictiveDistTransformedInitialValuesMenu');
%
% prior distribution
%
controls.predict.conditional.original.zlb.prior = uimenu('Parent',controls.predict.conditional.original.zlbmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ConPredPriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalZLBPredictiveDistOriginalPriorMenu');
%
controls.predict.conditional.annual.zlb.prior = uimenu('Parent',controls.predict.conditional.annual.zlbmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ConPredPriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalZLBPredictiveDistAnnualPriorMenu');
%
controls.predict.conditional.transformed.zlb.prior = uimenu('Parent',controls.predict.conditional.transformed.zlbmenu, ...
   'Label','P&rior Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ConPredPriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalZLBPredictiveDistTransformedPriorMenu');
%
% Posterior mode
%
controls.predict.conditional.original.zlb.postmode = uimenu('Parent',controls.predict.conditional.original.zlbmenu, ...
   'Label','&Posterior Mode...', ...
   'Callback','ZLBForecastToolsMenuFunctions ConPredPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalZLBPredictiveDistOriginalPostModeMenu');
%
controls.predict.conditional.annual.zlb.postmode = uimenu('Parent',controls.predict.conditional.annual.zlbmenu, ...
   'Label','&Posterior Mode...', ...
   'Callback','ZLBForecastToolsMenuFunctions ConPredPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalZLBPredictiveDistAnnualPostModeMenu');
%
controls.predict.conditional.transformed.zlb.postmode = uimenu('Parent',controls.predict.conditional.transformed.zlbmenu, ...
   'Label','&Posterior Mode...', ...
   'Callback','ZLBForecastToolsMenuFunctions ConPredPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','ConditionalZLBPredictiveDistTransformedPostModeMenu');
%
% posterior distribution
%
controls.predict.conditional.original.zlb.posterior = uimenu('Parent',controls.predict.conditional.original.zlbmenu, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ConPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalZLBPredictiveDistOriginalPosteriorMenu');
%
controls.predict.conditional.annual.zlb.posterior = uimenu('Parent',controls.predict.conditional.annual.zlbmenu, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ConPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalZLBPredictiveDistAnnualPosteriorMenu');
%
controls.predict.conditional.transformed.zlb.posterior = uimenu('Parent',controls.predict.conditional.transformed.zlbmenu, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ZLBForecastToolsMenuFunctions ConPredPosteriorDist', ...
   'Enable','off', ...
   'Tag','ConditionalZLBPredictiveDistTransformedPosteriorMenu');
%
% decompositions
%
controls.decomp.parent = uimenu('Parent',controls.toolsmenu, ...
   'Separator','on', ...
   'Label','&Decompositions', ...
   'Tag','DecompositionsMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                  Historical forecast error decompositions                   %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.hd.parent = uimenu('Parent',controls.decomp.parent, ...
   'Label','&Forecast Errors', ...
   'Tag','HDMenu');
%
% initial values
%
controls.hd.initialvalues = uimenu('Parent',controls.hd.parent, ...
   'Label','&Initial Values...', ...
   'Callback','DecompToolsMenuFunctions HFEDecompInitialValues', ...
   'Enable','off', ...
   'Tag','HDInitialValuesMenu');
%
% prior distribution
%
controls.hd.prior = uimenu('Parent',controls.hd.parent, ...
   'Label','P&rior Distribution...', ...
   'Callback','DecompToolsMenuFunctions HFEDecompPriorDist', ...
   'Enable','off', ...
   'Tag','HDPriorDistMenu');
%
% posterior mode
%
controls.hd.postmode = uimenu('Parent',controls.hd.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','DecompToolsMenuFunctions HFEDecompPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','HDPosteriorModeMenu');
%
% posterior distribution
%
controls.hd.posterior = uimenu('Parent',controls.hd.parent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','DecompToolsMenuFunctions HFEDecompPosteriorDist', ...
   'Enable','off', ...
   'Tag','HDPosteriorDistMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                             Observation weights                             %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.obsweights.parent = uimenu('Parent',controls.decomp.parent, ...
   'Label','Observation &Weights', ...
   'Tag','ObsWeightMenu');
%
% decompositions
%
controls.obsweights.decomp.parent = uimenu('Parent',controls.obsweights.parent, ...
   'Label','&Decompositions', ...
   'Tag','DecompObsWeightMenu');
%
controls.obsweights.decomp.states.parent = uimenu('Parent',controls.obsweights.decomp.parent, ...
   'Label','State &Variables', ...
   'Tag','StateDecompObsWeightMenu');
%
controls.obsweights.decomp.shocks.parent = uimenu('Parent',controls.obsweights.decomp.parent, ...
   'Label','&Shocks', ...
   'Tag','ShockDecompObsWeightMenu');
%
% initial values
%
controls.obsweights.decomp.states.initialvalues = uimenu('Parent',controls.obsweights.decomp.states.parent, ...
   'Label','&Initial Values...', ...
   'Callback','DecompToolsMenuFunctions ObsWeightDecompInitialValues', ...
   'Enable','off', ...
   'Tag','StateDecompObsWeightInitialValuesMenu');
%
controls.obsweights.decomp.shocks.initialvalues = uimenu('Parent',controls.obsweights.decomp.shocks.parent, ...
   'Label','&Initial Values...', ...
   'Callback','DecompToolsMenuFunctions ObsWeightDecompInitialValues', ...
   'Enable','off', ...
   'Tag','ShockDecompObsWeightInitialValuesMenu');
%
% posterior mode
%
controls.obsweights.decomp.states.postmode = uimenu('Parent',controls.obsweights.decomp.states.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','DecompToolsMenuFunctions ObsWeightDecompPostMode', ...
   'Enable','off', ...
   'Tag','StateDecompObsWeightPosteriorModeMenu');
%
controls.obsweights.decomp.shocks.postmode = uimenu('Parent',controls.obsweights.decomp.shocks.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','DecompToolsMenuFunctions ObsWeightDecompPostMode', ...
   'Enable','off', ...
   'Tag','ShockDecompObsWeightPosteriorModeMenu');
%
% weights on observations
%
controls.obsweights.weights.parent = uimenu('Parent',controls.obsweights.parent, ...
   'Label','&Weights', ...
   'Tag','WeightsObsWeightMenu');
%
controls.obsweights.weights.states.parent = uimenu('Parent',controls.obsweights.weights.parent, ...
   'Label','State &Variables', ...
   'Tag','StateObsWeightMenu');
%
controls.obsweights.weights.shocks.parent = uimenu('Parent',controls.obsweights.weights.parent, ...
   'Label','&Shocks', ...
   'Tag','ShockObsWeightMenu');
%
% initial values
%
controls.obsweights.weights.states.initialvalues = uimenu('Parent',controls.obsweights.weights.states.parent, ...
   'Label','&Initial Values...', ...
   'Callback','DecompToolsMenuFunctions ObsWeightInitialValues', ...
   'Enable','off', ...
   'Tag','StateObsWeightInitialValuesMenu');
%
controls.obsweights.weights.shocks.initialvalues = uimenu('Parent',controls.obsweights.weights.shocks.parent, ...
   'Label','&Initial Values...', ...
   'Callback','DecompToolsMenuFunctions ObsWeightInitialValues', ...
   'Enable','off', ...
   'Tag','ShockObsWeightInitialValuesMenu');
%
% posterior mode
%
controls.obsweights.weights.states.postmode = uimenu('Parent',controls.obsweights.weights.states.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','DecompToolsMenuFunctions ObsWeightPostMode', ...
   'Enable','off', ...
   'Tag','StateObsWeightPosteriorModeMenu');
%
controls.obsweights.weights.shocks.postmode = uimenu('Parent',controls.obsweights.weights.shocks.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','DecompToolsMenuFunctions ObsWeightPostMode', ...
   'Enable','off', ...
   'Tag','ShockObsWeightPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                      Observed variable decompositions                       %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.ovd.parent = uimenu('Parent',controls.decomp.parent, ...
   'Label','&Observed Variables', ...
   'Separator','on', ...
   'Tag','OVDMenu');
%
% decompositions
%
controls.ovd.decompositions = uimenu('Parent',controls.ovd.parent, ...
   'Label','&Decompositions', ...
   'Tag','OVDecompositionsMenu');
%
% paths
%
controls.ovd.paths = uimenu('Parent',controls.ovd.parent, ...
   'Label','&Paths', ...
   'Tag','OVDPathsMenu');
%
% original values
%
controls.ovd.original = uimenu('Parent',controls.ovd.decompositions, ...
   'Label','&Original Data', ...
   'Tag','OVDOriginalMenu');
%
controls.ovp.original = uimenu('Parent',controls.ovd.paths, ...
   'Label','&Original Data', ...
   'Tag','OVDPathsOriginalMenu');
%
% annualized values
%
controls.ovd.annual = uimenu('Parent',controls.ovd.decompositions, ...
   'Label','&Annualized Data', ...
   'Tag','OVDAnnualMenu');
%
controls.ovp.annual = uimenu('Parent',controls.ovd.paths, ...
   'Label','&Annualized Data', ...
   'Tag','OVDPathsAnnualMenu');
%
% initial values
%
controls.ovd.initialvalues = uimenu('Parent',controls.ovd.original, ...
   'Label','&Initial Values...', ...
   'Callback','DecompToolsMenuFunctions ObsVarDecompInitialValues', ...
   'Enable','off', ...
   'Tag','OVDInitialValuesMenu');
%
controls.ovd.anninitialvalues = uimenu('Parent',controls.ovd.annual, ...
   'Label','&Initial Values...', ...
   'Callback','DecompToolsMenuFunctions ObsVarDecompInitialValues', ...
   'Enable','off', ...
   'Tag','OVDAnnualInitialValuesMenu');
%
controls.ovp.initialvalues = uimenu('Parent',controls.ovp.original, ...
   'Label','&Initial Values...', ...
   'Callback','DecompToolsMenuFunctions ObsVarPathInitialValues', ...
   'Enable','off', ...
   'Tag','OVDPathsInitialValuesMenu');
%
controls.ovp.anninitialvalues = uimenu('Parent',controls.ovp.annual, ...
   'Label','&Initial Values...', ...
   'Callback','DecompToolsMenuFunctions ObsVarPathInitialValues', ...
   'Enable','off', ...
   'Tag','OVDPathsAnnualInitialValuesMenu');
%
% prior distribution
%
controls.ovd.prior = uimenu('Parent',controls.ovd.original, ...
   'Label','P&rior Distribution...', ...
   'Callback','DecompToolsMenuFunctions ObsVarDecompPriorDist', ...
   'Enable','off', ...
   'Tag','OVDPriorDistributionMenu');
%
controls.ovd.annprior = uimenu('Parent',controls.ovd.annual, ...
   'Label','P&rior Distribution...', ...
   'Callback','DecompToolsMenuFunctions ObsVarDecompPriorDist', ...
   'Enable','off', ...
   'Tag','OVDAnnualPriorDistributionMenu');
%
controls.ovp.prior = uimenu('Parent',controls.ovp.original, ...
   'Label','P&rior Distribution...', ...
   'Callback','DecompToolsMenuFunctions ObsVarPathPriorDist', ...
   'Enable','off', ...
   'Tag','OVDPathsPriorDistributionMenu');
%
controls.ovp.annprior = uimenu('Parent',controls.ovp.annual, ...
   'Label','P&rior Distribution...', ...
   'Callback','DecompToolsMenuFunctions ObsVarPathPriorDist', ...
   'Enable','off', ...
   'Tag','OVDPathsAnnualPriorDistributionMenu');
%
% posterior mode
%
controls.ovd.postmode = uimenu('Parent',controls.ovd.original, ...
   'Label','&Posterior Mode...', ...
   'Callback','DecompToolsMenuFunctions ObsVarDecompPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','OVDPosteriorModeMenu');
%
controls.ovd.annpostmode = uimenu('Parent',controls.ovd.annual, ...
   'Label','&Posterior Mode...', ...
   'Callback','DecompToolsMenuFunctions ObsVarDecompPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','OVDAnnualPosteriorModeMenu');
%
controls.ovp.postmode = uimenu('Parent',controls.ovp.original, ...
   'Label','&Posterior Mode...', ...
   'Callback','DecompToolsMenuFunctions ObsVarPathPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','OVDPathsPosteriorModeMenu');
%
controls.ovp.annpostmode = uimenu('Parent',controls.ovp.annual, ...
   'Label','&Posterior Mode...', ...
   'Callback','DecompToolsMenuFunctions ObsVarPathPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','OVDPathsAnnualPosteriorModeMenu');
%
% posterior distribution
%
controls.ovd.posterior = uimenu('Parent',controls.ovd.original, ...
   'Label','Posterior &Distribution...', ...
   'Callback','DecompToolsMenuFunctions ObsVarDecompPosteriorDist', ...
   'Enable','off', ...
   'Tag','OVDPosteriorDistributionMenu');
%
controls.ovd.annposterior = uimenu('Parent',controls.ovd.annual, ...
   'Label','Posterior &Distribution...', ...
   'Callback','DecompToolsMenuFunctions ObsVarDecompPosteriorDist', ...
   'Enable','off', ...
   'Tag','OVDAnnualPosteriorDistributionMenu');

controls.ovp.posterior = uimenu('Parent',controls.ovp.original, ...
   'Label','Posterior &Distribution...', ...
   'Callback','DecompToolsMenuFunctions ObsVarPathPosteriorDist', ...
   'Enable','off', ...
   'Tag','OVDPathsPosteriorDistributionMenu');
%
controls.ovp.annposterior = uimenu('Parent',controls.ovp.annual, ...
   'Label','Posterior &Distribution...', ...
   'Callback','DecompToolsMenuFunctions ObsVarPathPosteriorDist', ...
   'Enable','off', ...
   'Tag','OVDPathsAnnualPosteriorDistributionMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                        State variable decompositions                        %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.svd.parent = uimenu('Parent',controls.decomp.parent, ...
   'Label','S&tate Variables', ...
   'Tag','SVDMenu');
%
% Initial values
%
controls.svd.initialvalues = uimenu('Parent',controls.svd.parent, ...
   'Label','&Initial Values...', ...
   'Callback','DecompToolsMenuFunctions StateVarDecompInitialValues', ...
   'Enable','off', ...
   'Tag','SVDInitialValuesMenu');
%
% posterior mode
%
controls.svd.postmode = uimenu('Parent',controls.svd.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','DecompToolsMenuFunctions StateVarDecompPostMode', ...
   'Enable','off', ...
   'Tag','SVDPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                         Correlation decompositions                          %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.corrdecomp.parent = uimenu('Parent',controls.decomp.parent, ...
   'Label','Co&rrelation Decompositions', ...
   'Separator','on', ...
   'Tag','CorrelationDecompMenu');
%
% observed variables
%
controls.corrdecomp.obsvar.parent = uimenu('Parent',controls.corrdecomp.parent, ...
   'Label','&Observed Variables', ...
   'Tag','CorrelationDecompObsVarMenu');
%
% state variables
%
controls.corrdecomp.statevar.parent = uimenu('Parent',controls.corrdecomp.parent, ...
   'Label','&State Variables', ...
   'Tag','CorrelationDecompStateVarMenu');
%
% initial values
%
controls.corrdecomp.obsvar.initialvalues = uimenu('Parent',controls.corrdecomp.obsvar.parent, ...
   'Label','&Initial Values...', ...
   'Callback','DecompToolsMenuFunctions CorrDecompInitialValues', ...
   'Enable','off', ...
   'Tag','CorrelationDecompObsVarInitialValuesMenu');
%
controls.corrdecomp.statevar.initialvalues = uimenu('Parent',controls.corrdecomp.statevar.parent, ...
   'Label','&Initial Values...', ...
   'Callback','DecompToolsMenuFunctions CorrDecompInitialValues', ...
   'Enable','off', ...
   'Tag','CorrelationDecompStateVarInitialValuesMenu');
%
% posterior mode
%
controls.corrdecomp.obsvar.postmode = uimenu('Parent',controls.corrdecomp.obsvar.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','DecompToolsMenuFunctions CorrDecompPostMode', ...
   'Enable','off', ...
   'Tag','CorrelationDecompObsVarPosteriorModeMenu');
%
controls.corrdecomp.statevar.postmode = uimenu('Parent',controls.corrdecomp.statevar.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','DecompToolsMenuFunctions CorrDecompPostMode', ...
   'Enable','off', ...
   'Tag','CorrelationDecompStateVarPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                           Spectral decompositions                           %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.spectraldecomp.parent = uimenu('Parent',controls.decomp.parent, ...
   'Label','&Spectral Decompositions', ...
   'Tag','SpectralDecompMenu');
%
% observed variables
%
controls.spectraldecomp.obsvar.parent = uimenu('Parent',controls.spectraldecomp.parent, ...
   'Label','&Observed Variables', ...
   'Tag','SpectralDecompObsVarMenu');
%
% state variables
%
controls.spectraldecomp.statevar.parent = uimenu('Parent',controls.spectraldecomp.parent, ...
   'Label','&State Variables', ...
   'Tag','SpectralDecompStateVarMenu');
%
% initial values
%
controls.spectraldecomp.obsvar.initialvalues = uimenu('Parent',controls.spectraldecomp.obsvar.parent, ...
   'Label','&Initial Values...', ...
   'Callback','DecompToolsMenuFunctions SpectralDecompInitialValues', ...
   'Enable','off', ...
   'Tag','SpectralDecompObsVarInitialValuesMenu');
%
controls.spectraldecomp.statevar.initialvalues = uimenu('Parent',controls.spectraldecomp.statevar.parent, ...
   'Label','&Initial Values...', ...
   'Callback','DecompToolsMenuFunctions SpectralDecompInitialValues', ...
   'Enable','off', ...
   'Tag','SpectralDecompStateVarInitialValuesMenu');
%
% posterior mode
%
controls.spectraldecomp.obsvar.postmode = uimenu('Parent',controls.spectraldecomp.obsvar.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','DecompToolsMenuFunctions SpectralDecompPostMode', ...
   'Enable','off', ...
   'Tag','SpectralDecompObsVarPosteriorModeMenu');
%
controls.spectraldecomp.statevar.postmode = uimenu('Parent',controls.spectraldecomp.statevar.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','DecompToolsMenuFunctions SpectralDecompPostMode', ...
   'Enable','off', ...
   'Tag','SpectralDecompStateVarPosteriorModeMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                   Forecast error variance decompositions                    %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.fevd.parent = uimenu('Parent',controls.decomp.parent, ...
   'Separator','on', ...
   'Label','&Variance Decompositions', ...
   'Tag','FEVDMenu');
%
% original data
%
controls.fevd.original = uimenu('Parent',controls.fevd.parent, ...
   'Label','&Original Data', ...
   'Tag','FEVDOriginalMenu');
%
% levels data
%
controls.fevd.levels = uimenu('Parent',controls.fevd.parent, ...
   'Label','&Levels Data', ...
   'Tag','FVDLevelsMenu');
%
% state variables
%
controls.fevd.stateparent = uimenu('Parent',controls.fevd.parent, ...
   'Label','&State Variables', ...
   'Separator','on', ...
   'Tag','VDStateVariablesMenu');
%
% Initial values
%
controls.fevd.initialvalues = uimenu('Parent',controls.fevd.original, ...
   'Label','&Initial Values...', ...
   'Callback','DecompToolsMenuFunctions FEVDInitialValues', ...
   'Enable','off', ...
   'Tag','FEVDInitialValuesMenu');
%
controls.fevd.lev_initialvalues = uimenu('Parent',controls.fevd.levels, ...
   'Label','&Initial Values...', ...
   'Callback','DecompToolsMenuFunctions FEVDLevelsInitialValues', ...
   'Enable','off', ...
   'Tag','FEVDLevelsInitialValuesMenu');
%
% prior distribution
%
controls.fevd.prior = uimenu('Parent',controls.fevd.original, ...
   'Label','P&rior Distribution...', ...
   'Callback','DecompToolsMenuFunctions FEVDPriorDist', ...
   'Enable','off', ...
   'Tag','FEVDPriorDistMenu');
%
controls.fevd.lev_prior = uimenu('Parent',controls.fevd.levels, ...
   'Label','P&rior Distribution...', ...
   'Callback','DecompToolsMenuFunctions FEVDPriorDist', ...
   'Enable','off', ...
   'Tag','FEVDLevelsPriorDistMenu');
%
% posterior mode
%
controls.fevd.postmode = uimenu('Parent',controls.fevd.original, ...
   'Label','&Posterior Mode...', ...
   'Callback','DecompToolsMenuFunctions FEVDPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','FEVDPosteriorModeMenu');
%
controls.fevd.lev_postmode = uimenu('Parent',controls.fevd.levels, ...
   'Label','&Posterior Mode...', ...
   'Callback','DecompToolsMenuFunctions FEVDLevelsPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','FEVDLevelsPosteriorModeMenu');
%
% posterior distribution
%
controls.fevd.posterior = uimenu('Parent',controls.fevd.original, ...
   'Label','Posterior &Distribution...', ...
   'Callback','DecompToolsMenuFunctions FEVDPosteriorDist', ...
   'Enable','off', ...
   'Tag','FEVDPosteriorDistMenu');
%
controls.fevd.lev_posterior = uimenu('Parent',controls.fevd.levels, ...
   'Label','Posterior &Distribution...', ...
   'Callback','DecompToolsMenuFunctions FEVDPosteriorDist', ...
   'Enable','off', ...
   'Tag','FEVDLevelsPosteriorDistMenu');
%
% state variables
%
controls.fevd.state.initialvalues = uimenu('Parent',controls.fevd.stateparent, ...
   'Label','&Initial Values...', ...
   'Callback','DecompToolsMenuFunctions VDStateInitialValues', ...
   'Enable','off', ...
   'Tag','VDStateInitialValuesMenu');
%
controls.fevd.state.prior = uimenu('Parent',controls.fevd.stateparent, ...
   'Label','P&rior Distribution...', ...
   'Callback','DecompToolsMenuFunctions VDStatePriorDist', ...
   'Enable','off', ...
   'Tag','VDStatePriorDistributionMenu');
%
controls.fevd.state.postmode = uimenu('Parent',controls.fevd.stateparent, ...
   'Label','&Posterior Mode...', ...
   'Callback','DecompToolsMenuFunctions VDStatePostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','VDStatePosteriorModeMenu');
%
controls.fevd.state.posterior = uimenu('Parent',controls.fevd.stateparent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','DecompToolsMenuFunctions VDStatePosteriorDist', ...
   'Enable','off', ...
   'Tag','VDStatePosteriorDistMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%              Conditional forecast error variance decomposition              %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.cvd.parent = uimenu('Parent',controls.decomp.parent, ...
   'Label','&Conditional Variance Decompositions', ...
   'Tag','CVDMenu');
%
controls.cvd.original = uimenu('Parent',controls.cvd.parent, ...
   'Label','&Original Data', ...
   'Tag','CVDOriginalMenu');
%
controls.cvd.annual = uimenu('Parent',controls.cvd.parent, ...
   'Label','&Annualized Data', ...
   'Tag','CVDAnnualMenu');
%
controls.cvd.levels = uimenu('Parent',controls.cvd.parent, ...
   'Label','&Levels Data', ...
   'Tag','CVDLevelsMenu');
%
% state variables
%
controls.cvd.stateparent = uimenu('Parent',controls.cvd.parent, ...
   'Label','&State Variables', ...
   'Separator','on', ...
   'Tag','CVDStateVariablesMenu');
%
% Initial values
%
controls.cvd.initialvalues = uimenu('Parent',controls.cvd.original, ...
   'Label','&Initial Values...', ...
   'Callback','DecompToolsMenuFunctions CondVDInitialValues', ...
   'Enable','off', ...
   'Tag','CVDOrigInitialValuesMenu');
%
controls.cvd.ann_initialvalues = uimenu('Parent',controls.cvd.annual, ...
   'Label','&Initial Values...', ...
   'Callback','DecompToolsMenuFunctions CondVDAnnualInitialValues', ...
   'Enable','off', ...
   'Tag','CVDAnnualInitialValuesMenu');
%
controls.cvd.lev_initialvalues = uimenu('Parent',controls.cvd.levels, ...
   'Label','&Initial Values...', ...
   'Callback','DecompToolsMenuFunctions CondVDLevelsInitialValues', ...
   'Enable','off', ...
   'Tag','CVDLevelsInitialValuesMenu');
%
controls.cvd.state.initialvalues = uimenu('Parent',controls.cvd.stateparent, ...
   'Label','&Initial Values...', ...
   'Callback','DecompToolsMenuFunctions CondVDStateInitialValues', ...
   'Enable','off', ...
   'Tag','CVDStateInitialValuesMenu');
%
% prior distribution
%
controls.cvd.prior = uimenu('Parent',controls.cvd.original, ...
   'Label','P&rior Distribution...', ...
   'Callback','DecompToolsMenuFunctions CondVDPriorDist', ...
   'Enable','off', ...
   'Tag','CVDOrigPriorDistMenu');
%
controls.cvd.ann_prior = uimenu('Parent',controls.cvd.annual, ...
   'Label','P&rior Distribution...', ...
   'Callback','DecompToolsMenuFunctions CondVDPriorDist', ...
   'Enable','off', ...
   'Tag','CVDAnnualPriorDistMenu');
%
controls.cvd.lev_prior = uimenu('Parent',controls.cvd.levels, ...
   'Label','P&rior Distribution...', ...
   'Callback','DecompToolsMenuFunctions CondVDPriorDist', ...
   'Enable','off', ...
   'Tag','CVDLevelsPriorDistMenu');
%
controls.cvd.state.prior = uimenu('Parent',controls.cvd.stateparent, ...
   'Label','P&rior Distribution...', ...
   'Callback','DecompToolsMenuFunctions CondVDStatePriorDist', ...
   'Enable','off', ...
   'Tag','CVDStatePriorDistMenu');
%
% posterior mode
%
controls.cvd.postmode = uimenu('Parent',controls.cvd.original, ...
   'Label','&Posterior Mode...', ...
   'Callback','DecompToolsMenuFunctions CondVDPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','CVDOrigPosteriorModeMenu');
%
controls.cvd.ann_postmode = uimenu('Parent',controls.cvd.annual, ...
   'Label','&Posterior Mode...', ...
   'Callback','DecompToolsMenuFunctions CondVDAnnualPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','CVDAnnualPosteriorModeMenu');
%
controls.cvd.lev_postmode = uimenu('Parent',controls.cvd.levels, ...
   'Label','&Posterior Mode...', ...
   'Callback','DecompToolsMenuFunctions CondVDLevelsPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','CVDLevelsPosteriorModeMenu');
%
controls.cvd.state.postmode = uimenu('Parent',controls.cvd.stateparent, ...
   'Label','&Posterior Mode...', ...
   'Callback','DecompToolsMenuFunctions CondVDStatePostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','CVDStatePosteriorModeMenu');
%
% posterior distribution
%
controls.cvd.posterior = uimenu('Parent',controls.cvd.original, ...
   'Label','Posterior &Distribution...', ...
   'Callback','DecompToolsMenuFunctions CondVDPosteriorDist', ...
   'Enable','off', ...
   'Tag','CVDOrigPosteriorDistMenu');
%
controls.cvd.ann_posterior = uimenu('Parent',controls.cvd.annual, ...
   'Label','Posterior &Distribution...', ...
   'Callback','DecompToolsMenuFunctions CondVDPosteriorDist', ...
   'Enable','off', ...
   'Tag','CVDAnnualPosteriorDistMenu');
%
controls.cvd.lev_posterior = uimenu('Parent',controls.cvd.levels, ...
   'Label','Posterior &Distribution...', ...
   'Callback','DecompToolsMenuFunctions CondVDPosteriorDist', ...
   'Enable','off', ...
   'Tag','CVDLevelsPosteriorDistMenu');
%
controls.cvd.state.posterior = uimenu('Parent',controls.cvd.stateparent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','DecompToolsMenuFunctions CondVDStatePosteriorDist', ...
   'Enable','off', ...
   'Tag','CVDStatePosteriorDistMenu');
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                             %
%                              Impulse responses                              %
%                                                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
controls.irfunctions.parent = uimenu('Parent',controls.toolsmenu, ...
   'Label','&Impulse Responses', ...
   'Tag','IRMenu');
%
controls.irfunctions.original = uimenu('Parent',controls.irfunctions.parent, ...
   'Label','&Original Data', ...
   'Tag','IROriginalMenu');
%
controls.irfunctions.annual = uimenu('Parent',controls.irfunctions.parent, ...
   'Label','&Annualized Data', ...
   'Tag','IRAnnualMenu');
%
controls.irfunctions.levels = uimenu('Parent',controls.irfunctions.parent, ...
   'Label','&Levels Data', ...
   'Tag','IRLevelsMenu');
%
controls.irfunctions.statevariablesparent = uimenu('Parent',controls.irfunctions.parent, ...
   'Label','&State Variables', ...
   'Tag','IRStateVariablesMenu');
%
controls.irfunctions.permanentshockparent = uimenu('Parent',controls.irfunctions.parent, ...
   'Label','&Permanent Shock', ...
   'Separator','on', ...
   'Tag','IRPermanentShockMenu');
%
controls.irfunctions.parameterchange.parent = uimenu('Parent',controls.irfunctions.parent, ...
   'Label','Parameter &Change', ...
   'Separator','on', ...
   'Tag','IRParameterChangeMenu');
%
% Initial values
%
controls.irfunctions.initialvalues = uimenu('Parent',controls.irfunctions.original, ...
   'Label','&Initial Values...', ...
   'Callback','ToolsMenuFunctions IRInitialValues', ...
   'Enable','off', ...
   'Tag','IRInitialValuesMenu');
%
controls.irfunctions.ann_initialvalues = uimenu('Parent',controls.irfunctions.annual, ...
   'Label','&Initial Values...', ...
   'Callback','ToolsMenuFunctions IRAnnualInitialValues', ...
   'Enable','off', ...
   'Tag','IRInitialValuesMenu');
%
controls.irfunctions.lev_initialvalues = uimenu('Parent',controls.irfunctions.levels, ...
   'Label','&Initial Values...', ...
   'Callback','ToolsMenuFunctions IRLevelsInitialValues', ...
   'Enable','off', ...
   'Tag','IRLevelsInitialValuesMenu');
%
% prior distributions
%
controls.irfunctions.prior = uimenu('Parent',controls.irfunctions.original, ...
   'Label','P&rior Distribution...', ...
   'Callback','ToolsMenuFunctions IRPriorDist', ...
   'Enable','off', ...
   'Tag','IRPriorDistMenu');
%
controls.irfunctions.ann_prior = uimenu('Parent',controls.irfunctions.annual, ...
   'Label','P&rior Distribution...', ...
   'Callback','ToolsMenuFunctions IRPriorDist', ...
   'Enable','off', ...
   'Tag','IRAnnualPriorDistMenu');
%
controls.irfunctions.lev_prior = uimenu('Parent',controls.irfunctions.levels, ...
   'Label','P&rior Distribution...', ...
   'Callback','ToolsMenuFunctions IRPriorDist', ...
   'Enable','off', ...
   'Tag','IRLevelsPriorDistMenu');
%
controls.irfunctions.statevariables.prior = uimenu('Parent',controls.irfunctions.statevariablesparent, ...
   'Label','P&rior Distribution...', ...
   'Callback','ToolsMenuFunctions IRStateVarsPriorDist', ...
   'Enable','off', ...
   'Tag','IRStateVarsPriorDistMenu');
%
% posterior mode
%
controls.irfunctions.postmode = uimenu('Parent',controls.irfunctions.original, ...
   'Label','&Posterior Mode...', ...
   'Callback','ToolsMenuFunctions IRPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','IRPosteriorModeMenu');
% 
controls.irfunctions.ann_postmode = uimenu('Parent',controls.irfunctions.annual, ...
   'Label','&Posterior Mode...', ...
   'Callback','ToolsMenuFunctions IRAnnualPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','IRAnnualPosteriorModeMenu');
%
controls.irfunctions.lev_postmode = uimenu('Parent',controls.irfunctions.levels, ...
   'Label','&Posterior Mode...', ...
   'Callback','ToolsMenuFunctions IRLevelsPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','IRLevelsPosteriorModeMenu');
%
% posterior distributions
%
controls.irfunctions.posterior = uimenu('Parent',controls.irfunctions.original, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ToolsMenuFunctions IRPosteriorDist', ...
   'Enable','off', ...
   'Tag','IRPosteriorDistMenu');
%
controls.irfunctions.ann_posterior = uimenu('Parent',controls.irfunctions.annual, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ToolsMenuFunctions IRPosteriorDist', ...
   'Enable','off', ...
   'Tag','IRAnnualPosteriorDistMenu');
%
controls.irfunctions.lev_posterior = uimenu('Parent',controls.irfunctions.levels, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ToolsMenuFunctions IRPosteriorDist', ...
   'Enable','off', ...
   'Tag','IRLevelsPosteriorDistMenu');
%
controls.irfunctions.statevariables.posterior = uimenu('Parent',controls.irfunctions.statevariablesparent, ...
   'Label','Posterior &Distribution...', ...
   'Callback','ToolsMenuFunctions IRStateVarsPosteriorDist', ...
   'Enable','off', ...
   'Tag','IRStateVarsPosteriorDistMenu');
%
% permanent shock
%
controls.irfunctions.permanentshock.initialvalues = uimenu('Parent',controls.irfunctions.permanentshockparent, ...
   'Label','&Initial Values...', ...
   'Callback','ToolsMenuFunctions IRPermanentShockInitialValues', ...
   'Enable','off', ...
   'Tag','IRPermanentShockInitialValuesMenu');
%
controls.irfunctions.permanentshock.postmode = uimenu('Parent',controls.irfunctions.permanentshockparent, ...
   'Label','&Posterior Mode...', ...
   'Callback','ToolsMenuFunctions IRPermanentShockPostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','IRPermanentShockPosteriorModeMenu');
%
% parameter change
%
controls.irfunctions.parameterchange.initialvalues = uimenu('Parent',controls.irfunctions.parameterchange.parent, ...
   'Label','&Initial Values...', ...
   'Callback','ToolsMenuFunctions IRParameterChangeInitialValues', ...
   'Enable','off', ...
   'Tag','IRParameterChangeInitialValuesMenu');
%
controls.irfunctions.parameterchange.postmode = uimenu('Parent',controls.irfunctions.parameterchange.parent, ...
   'Label','&Posterior Mode...', ...
   'Callback','ToolsMenuFunctions IRParameterChangePostMode', ...
   'Separator','on', ...
   'Enable','off', ...
   'Tag','IRParameterChangePosteriorModeMenu');

%
% end of ToolsMenuControls.m
%
